@@ -35,10 +35,7 @@ from pgn_read.core.constants import (
 )
 from pgn_read.core.squares import Squares
 
-from ..core.constants import (
-    MOVE_NUMBER_KEYS,
-)
-from .rayfilter import RayFilter, move_number_str
+from .rayfilter import move_number_str
 from ..core.filespec import (
     PIECESQUAREMOVE_FIELD_DEF,
     PIECEMOVE_FIELD_DEF,
@@ -48,7 +45,6 @@ from ..core.filespec import (
     NEWGAMES_FIELD_VALUE,
     PARTIALPOSITION_FIELD_DEF,
 )
-from ..core.chessrecord import ChessDBrecordGameUpdate
 
 # The immediate children of nodes with the names of these filters have 'and'
 # and 'or' applied to evaluate the node's answer.
@@ -86,14 +82,14 @@ del _filters
 
 
 class ChessQLGamesError(Exception):
-    pass
+    """Exception class for cqlgames module."""
 
 
 class ChessQLGames:
-
     """Represent subset of games that match a Chess Query Language query."""
 
     def __init__(self, *a, **k):
+        """Delete then create Find instance for queries."""
         super().__init__(*a, **k)
 
         # recordclass argument must be used to support non-index field finds.
@@ -164,9 +160,9 @@ class ChessQLGames:
             initial_recordlist = self.dbhome.recordlist_nil(self.dbset)
             initial_recordlist |= initial_recordset
         query = sourceobject.value
-        games = self.get_games_matching_filters(
+        games = self._get_games_matching_filters(
             query,
-            self.get_games_matching_parameters(query, initial_recordlist),
+            self._get_games_matching_parameters(query, initial_recordlist),
         )
 
         # File the list of games under the query key.
@@ -213,6 +209,7 @@ class ChessQLGames:
         initial_recordset is games to which query is applied.
 
         """
+        del commit
         if query is None:
             self.set_recordset(self.dbhome.recordlist_nil(self.dbset))
             return
@@ -257,9 +254,9 @@ class ChessQLGames:
         else:
             initial_recordlist = self.dbhome.recordlist_nil(self.dbset)
             initial_recordlist |= initial_recordset
-        games = self.get_games_matching_filters(
+        games = self._get_games_matching_filters(
             query,
-            self.get_games_matching_parameters(query, initial_recordlist),
+            self._get_games_matching_parameters(query, initial_recordlist),
         )
 
         # Hand the list of games over to the user interface.
@@ -278,44 +275,44 @@ class ChessQLGames:
         """
         if filter_.tokendef in _AND_FILTERS:
             pieces = set(initialpieces)
-            for n in filter_.children:
-                if n.tokendef is Token.PIECE_DESIGNATOR:
+            for node in filter_.children:
+                if node.tokendef is Token.PIECE_DESIGNATOR:
                     pieces.intersection_update(
-                        self.pieces_matching_piece_designator(n)
+                        self.pieces_matching_piece_designator(node)
                     )
                     if not pieces:
                         return pieces
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
                 pieces.intersection_update(
-                    self.pieces_matching_filter(n, pieces)
+                    self.pieces_matching_filter(node, pieces)
                 )
                 if not pieces:
                     return pieces
             return pieces
-        elif filter_.tokendef in _OR_FILTERS:
+        if filter_.tokendef in _OR_FILTERS:
             pieces = set(ALL_PIECES)
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
 
                 # This cannot be correct given pieces initialisation, or
                 # more likely pieces initialisation is not correct too.
                 # However pieces_matching_filter is not called anywhere!
-                pieces.union(self.pieces_matching_filter(n, initialpieces))
+                pieces.union(self.pieces_matching_filter(node, initialpieces))
 
             return pieces
-        else:
-            if filter_.tokendef is Token.PIECE_DESIGNATOR:
-                return self.pieces_matching_piece_designator(filter_)
-            return initialpieces
+        if filter_.tokendef is Token.PIECE_DESIGNATOR:
+            return self.pieces_matching_piece_designator(filter_)
+        return initialpieces
 
     # Not called anywhere.
     # Introduced at revision 3755 as part of 'on' filter implementation which
     # has been, at least temporarely, removed.
     # Called _squares_matching_filter then.
-    def squares_matching_filter(self, filter_, initialsquares):
+    # And back to _squares_matching_filter again! (revision 5067)
+    def _squares_matching_filter(self, filter_, initialsquares):
         """Return squares matching filters in CQL statement.
 
         It is assumed FSNode.designator_set contains the expanded piece
@@ -324,42 +321,43 @@ class ChessQLGames:
         """
         if filter_.tokendef in _AND_FILTERS:
             squares = set(initialsquares)
-            for n in filter_.children:
-                if n.tokendef is Token.PIECE_DESIGNATOR:
+            for node in filter_.children:
+                if node.tokendef is Token.PIECE_DESIGNATOR:
                     squares.intersection_update(
-                        self.squares_matching_piece_designator(n)
+                        self.squares_matching_piece_designator(node)
                     )
                     if not squares:
                         return squares
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
                 squares.intersection_update(
-                    self.squares_matching_filter(n, squares)
+                    self._squares_matching_filter(node, squares)
                 )
                 if not squares:
                     return squares
             return squares
-        elif filter_.tokendef in _OR_FILTERS:
+        if filter_.tokendef in _OR_FILTERS:
             squares = set(Squares.squares)
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
 
                 # This cannot be correct given squares initialisation, or
                 # more likely squares initialisation is not correct too.
-                # However squares_matching_filter is not called anywhere!
-                squares.union(self.squares_matching_filter(n, initialsquares))
+                # However _squares_matching_filter is not called anywhere!
+                squares.union(
+                    self._squares_matching_filter(node, initialsquares)
+                )
 
             return squares
-        else:
-            if filter_.tokendef is Token.PIECE_DESIGNATOR:
-                return self.squares_matching_piece_designator(filter_)
-            return initialsquares
+        if filter_.tokendef is Token.PIECE_DESIGNATOR:
+            return self.squares_matching_piece_designator(filter_)
+        return initialsquares
 
-    def pieces_matching_piece_designator(self, filter_):
+    @staticmethod
+    def pieces_matching_piece_designator(filter_):
         """Return pieces matching a piece designator."""
-
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
             raise ChessQLGamesError(
                 "".join(
@@ -373,19 +371,19 @@ class ChessQLGames:
                 )
             )
         pieces = set()
-        for ps in filter_.data.designator_set:
-            p = ps[0]
-            if p == ANY_WHITE_PIECE_NAME:
+        for pdesignator in filter_.data.designator_set:
+            piece = pdesignator[0]
+            if piece == ANY_WHITE_PIECE_NAME:
                 pieces.update(WHITE_PIECE_NAMES)
-            elif p == ANY_BLACK_PIECE_NAME:
+            elif piece == ANY_BLACK_PIECE_NAME:
                 pieces.update(BLACK_PIECE_NAMES)
             else:
-                pieces.add(p)
+                pieces.add(piece)
         return pieces
 
-    def squares_matching_piece_designator(self, filter_):
+    @staticmethod
+    def squares_matching_piece_designator(filter_):
         """Return squares matching a piece designator."""
-
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
             raise ChessQLGamesError(
                 "".join(
@@ -399,14 +397,14 @@ class ChessQLGames:
                 )
             )
         squares = set()
-        for ps in filter_.data.designator_set:
-            if len(ps) == 1:
+        for pdesignator in filter_.data.designator_set:
+            if len(pdesignator) == 1:
                 squares.update(Squares.squares)
             else:
-                squares.add(ps[1:])
+                squares.add(pdesignator[1:])
         return squares
 
-    def is_filter_not_implemented(self, filter_):
+    def _is_filter_not_implemented(self, filter_):
         """Return True if filter is not implemented, and False otherwise.
 
         Filters which are not implemented are added to a list reported before
@@ -422,7 +420,6 @@ class ChessQLGames:
         self, filter_, datasource, movenumber, variation
     ):
         """Return games matching a piece designator."""
-
         if filter_.tokendef is not Token.PIECE_DESIGNATOR:
             raise ChessQLGamesError(
                 "".join(
@@ -452,52 +449,48 @@ class ChessQLGames:
         if filter_.tokendef in _AND_FILTERS:
             games = self.dbhome.recordlist_nil(self.dbset)
             games |= initialgames
-            for n in filter_.children:
-                if n.tokendef is Token.PIECE_DESIGNATOR:
+            for node in filter_.children:
+                if node.tokendef is Token.PIECE_DESIGNATOR:
                     games &= self._games_matching_piece_designator(
-                        n, games, movenumber, variation
+                        node, games, movenumber, variation
                     )
                     if not games.count_records():
                         return games
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
                 games &= self._games_matching_filter(
-                    n, games, movenumber, variation
+                    node, games, movenumber, variation
                 )
                 if not games.count_records():
                     return games
             return games
-        elif filter_.tokendef in _OR_FILTERS:
+        if filter_.tokendef in _OR_FILTERS:
             games = self.dbhome.recordlist_nil(self.dbset)
-            for n in filter_.children:
-                if self.is_filter_not_implemented(n):
+            for node in filter_.children:
+                if self._is_filter_not_implemented(node):
                     continue
-                e = self._games_matching_filter(
-                    n, initialgames, movenumber, variation
-                )
                 games |= self._games_matching_filter(
-                    n, initialgames, movenumber, variation
+                    node, initialgames, movenumber, variation
                 )
             return games
-        else:
-            if filter_.tokendef is Token.PIECE_DESIGNATOR:
-                return self._games_matching_piece_designator(
-                    filter_, initialgames, movenumber, variation
-                )
-            if filter_.tokendef is Token.RAY:
-                return self._games_matching_ray_filter(
-                    filter_, initialgames, movenumber, variation
-                )
-            games = self.dbhome.recordlist_nil(self.dbset)
-            games |= initialgames
-            return games
+        if filter_.tokendef is Token.PIECE_DESIGNATOR:
+            return self._games_matching_piece_designator(
+                filter_, initialgames, movenumber, variation
+            )
+        if filter_.tokendef is Token.RAY:
+            return self._games_matching_ray_filter(
+                filter_, initialgames, movenumber, variation
+            )
+        games = self.dbhome.recordlist_nil(self.dbset)
+        games |= initialgames
+        return games
 
     def _games_matching_ray_filter(
         self, filter_, datasource, movenumber, variation
     ):
         """Return games matching a ray filter."""
-
+        del datasource
         if filter_.tokendef is not Token.RAY:
             raise ChessQLGamesError(
                 "".join(
@@ -510,40 +503,60 @@ class ChessQLGames:
                     )
                 )
             )
-        rf = RayFilter(filter_, movenumber, variation)
-        rf.prune_end_squares(self.dbhome)
-        rf.find_games_for_end_squares(self.cqlfinder)
-        rf.find_games_for_middle_squares(self.cqlfinder)
-
-        # So that downstream methods have a valid object to work with.
-        recordset = self.dbhome.recordlist_nil(self.dbset)
-        for gs in rf.ray_games.values():
-            recordset |= gs
+        ray_games = filter_.data.find_games(
+            movenumber,
+            variation,
+            self._evaluate_ray_filter_element,
+        )
+        if ray_games:
+            recordset = self.dbhome.recordlist_ebm(self.dbset)
+            for value in ray_games.values():
+                recordset &= value
+        else:
+            recordset = self.dbhome.recordlist_nil(self.dbset)
         return recordset
 
     def _evaluate_piece_designator(
         self, move_number, variation_code, piecesquares
     ):
-        """Return foundset calculated for piece designator using where class.
+        """Return games for piecesquares at move_number and variation_code.
 
-        The fieldname PieceSquareMove is now unavoidably a bit confusing, where
-        move refers to a token in the movetext when the piece is on the square.
-        Nothing to do with move number in the movetext, which is the ChessQL
-        meaning of move in this context.
+        The return value is a RecordList instance.
+
+        The move, variation, and piece designator need to be transformed
+        into a value which potentially exists on the database.
 
         """
-        w = Where(
+        return self._evaluate_statement(
             where_eq_piece_designator(
                 move_number, variation_code, piecesquares
             )
         )
-        w.lex()
-        w.parse()
-        v = w.validate(self.cqlfinder.db, self.cqlfinder.dbset)
-        w.evaluate(self.cqlfinder)
-        return w.get_node_result_answer()
 
-    def get_games_matching_filters(self, query, games):
+    def _evaluate_ray_filter_element(self, move_variation_square_piece):
+        """Return games for move_variation_square_piece.
+
+        The return value is a RecordList instance.
+
+        The move, variation, square, and piece, have already been turned
+        into a value which potentially exists on the database: no further
+        transformation of the value is needed.
+
+        """
+        return self._evaluate_statement(
+            where_eq_ray_element(move_variation_square_piece)
+        )
+
+    def _evaluate_statement(self, statement):
+        """Return foundset calcualted from statement."""
+        wqs = Where(statement)
+        wqs.lex()
+        wqs.parse()
+        wqs.validate(self.cqlfinder.db, self.cqlfinder.dbset)
+        wqs.evaluate(self.cqlfinder)
+        return wqs.get_node_result_answer()
+
+    def _get_games_matching_filters(self, query, games):
         """Select the games which meet the ChessQL cql() ... filters.
 
         Walk node tree for every movenumber and combine evaluated game sets.
@@ -552,7 +565,7 @@ class ChessQLGames:
         found = self.dbhome.recordlist_nil(self.dbset)
         if not query.cql_filters:
             return found
-        query.cql_filters.expand_child_piece_designators()
+        query.cql_filters.expand_set_filters()
         key = self._get_high_move_number()
         if key is None:
             return found
@@ -563,13 +576,14 @@ class ChessQLGames:
             )
         return found
 
-    # Version of get_games_matching_filters() to process CQL parameters.
-    def get_games_matching_parameters(self, query, games):
-        """Select the games which meet the ChessQL cql(...) parameters
+    # Version of _get_games_matching_filters() to process CQL parameters.
+    def _get_games_matching_parameters(self, query, games):
+        """Select the games which meet the ChessQL cql(...) parameters.
 
         Walk node tree for cql parameters and combine evaluated game sets.
 
         """
+        del query
         found = self.dbhome.recordlist_nil(self.dbset)
         found |= games
         return found
@@ -605,12 +619,12 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
     pmds = set()
     emptyds = set()
     smds = set()
-    for ps in designator_set:
-        if len(ps) == 1:
+    for pdesignator in designator_set:
+        if len(pdesignator) == 1:
 
             # Rules of chess imply whole piece designator finds all games if
             # any of 'A', 'a', 'K', 'k', and '_', are in designator set.
-            if ps[0] in ALL_GAMES_MATCH_PIECE_DESIGNATORS:
+            if pdesignator[0] in ALL_GAMES_MATCH_PIECE_DESIGNATORS:
                 return " ".join(
                     (
                         pmfield,
@@ -619,21 +633,10 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
                     )
                 )
 
-            pmds.add("".join((mns, variation_code, ps[0])))
+            pmds.add("".join((mns, variation_code, pdesignator[0])))
             continue
-        if ps[0] == EMPTY_SQUARE_NAME:
-            sq = ps[1:]
-
-            # 'not field eq value1 or value2' does not work, it should, but
-            # 'not field eq value1 and not field eq value2' does work.
-            # emptyds.add(' '.join(
-            #    (NOT,
-            #     smfield,
-            #     EQ,
-            #     ''.join((mns, variation_code, sq + ANY_WHITE_PIECE_NAME)),
-            #     OR,
-            #     ''.join((mns, variation_code, sq + ANY_BLACK_PIECE_NAME)),
-            #     )))
+        if pdesignator[0] == EMPTY_SQUARE_NAME:
+            sqr = pdesignator[1:]
             emptyds.add(
                 " ".join(
                     (
@@ -641,27 +644,33 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
                         smfield,
                         EQ,
                         "".join(
-                            (mns, variation_code, sq + ANY_WHITE_PIECE_NAME)
+                            (mns, variation_code, sqr + ANY_WHITE_PIECE_NAME)
                         ),
                         AND,
                         NOT,
                         smfield,
                         EQ,
                         "".join(
-                            (mns, variation_code, sq + ANY_BLACK_PIECE_NAME)
+                            (mns, variation_code, sqr + ANY_BLACK_PIECE_NAME)
                         ),
+                        # Restrict sets generated by NOTs to games active at
+                        # <mns, variation_code>.  'K' or 'k'  achieve this
+                        # from the rules of chess.
+                        AND,
+                        pmfield,
+                        EQ,
+                        "".join((mns, variation_code, FEN_WHITE_KING)),
                     )
                 )
             )
-
             continue
-        if ps[0] in anypiece:
+        if pdesignator[0] in anypiece:
             smds.add(
                 "".join(
                     (
                         mns,
                         variation_code,
-                        ps[1:] + ps[0],
+                        pdesignator[1:] + pdesignator[0],
                     )
                 )
             )
@@ -671,7 +680,7 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
                 (
                     mns,
                     variation_code,
-                    ps[1:] + ps[0],
+                    pdesignator[1:] + pdesignator[0],
                 )
             )
         )
@@ -687,6 +696,61 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
         phrases.append(OR.join("  ").join(emptyds))
     if phrases:
         return OR.join("  ").join(phrases)
+    return None
+
+
+def where_eq_ray_element(move_variation_square_piece):
+    """Return list of selection phrases to evaluate a ray element.
+
+    move_variation_square_piece is named for the order of the values of
+    which it is composed.  THe value is to be placed in a 'where' clause.
+
+    """
+    anypiece = ANY_WHITE_PIECE_NAME + ANY_BLACK_PIECE_NAME
+    psmfield = PIECESQUAREMOVE_FIELD_DEF
+    pmfield = PIECEMOVE_FIELD_DEF
+    smfield = SQUAREMOVE_FIELD_DEF
+    psmds = set()
+    emptyds = set()
+    smds = set()
+    if move_variation_square_piece[-1] == EMPTY_SQUARE_NAME:
+        emptyds.add(
+            " ".join(
+                (
+                    NOT,
+                    smfield,
+                    EQ,
+                    move_variation_square_piece[:-1] + ANY_WHITE_PIECE_NAME,
+                    AND,
+                    NOT,
+                    smfield,
+                    EQ,
+                    move_variation_square_piece[:-1] + ANY_BLACK_PIECE_NAME,
+                    # Restrict sets generated by NOTs to games active at
+                    # <mns, variation_code>.  'K' or 'k'  achieve this
+                    # from the rules of chess.
+                    AND,
+                    pmfield,
+                    EQ,
+                    move_variation_square_piece[:-3] + FEN_WHITE_KING,
+                )
+            )
+        )
+    elif move_variation_square_piece[-1] in anypiece:
+        smds.add(move_variation_square_piece)
+    else:
+        psmds.add(move_variation_square_piece)
+
+    phrases = []
+    if psmds:
+        phrases.append(" ".join((psmfield, EQ, OR.join("  ").join(psmds))))
+    if smds:
+        phrases.append(" ".join((smfield, EQ, OR.join("  ").join(smds))))
+    if emptyds:
+        phrases.append(OR.join("  ").join(emptyds))
+    if phrases:
+        return OR.join("  ").join(phrases)
+    return None
 
 
 # def move_number_str(move_number):
@@ -703,5 +767,5 @@ def where_eq_piece_designator(move_number, variation_code, designator_set):
 
 def move_number_in_key_range(key):
     """Yield the move number keys in a range one-by-one."""
-    for n in range(1, literal_eval("0x" + key[1 : int(key[0]) + 1])):
-        yield n
+    for number in range(1, literal_eval("0x" + key[1 : int(key[0]) + 1])):
+        yield number
