@@ -2,8 +2,7 @@
 # Copyright 2019 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""ChessTab database methods common to all database engine interfaces.
-"""
+"""ChessTab database methods common to all database engine interfaces."""
 
 import os
 import bz2
@@ -18,8 +17,7 @@ from .. import APPLICATION_NAME, ERROR_LOG
 
 
 class Database:
-
-    """ """
+    """Define methods which are common to all database engine interfaces."""
 
     def use_deferred_update_process(self, **kargs):
         """Return path to deferred update module.
@@ -27,6 +25,7 @@ class Database:
         **kargs - soak up any arguments other database engines need.
 
         """
+        del kargs
         return self._deferred_update_process
 
     def open_database(self, files=None):
@@ -34,64 +33,74 @@ class Database:
         super().open_database(files=files)
         return True
 
-    def dump_database(self, names=()):
+    @staticmethod
+    def dump_database(names=()):
         """Dump database in compressed files."""
-        for n in names:
-            c = bz2.BZ2Compressor()
-            archivename = ".".join((n, "broken", "bz2"))
-            fi = open(n, "rb")
-            fo = open(archivename, "wb")
-            try:
-                inp = fi.read(10000000)
+        for name in names:
+            compressor = bz2.BZ2Compressor()
+            archivename = ".".join((name, "broken", "bz2"))
+            with open(name, "rb") as file_in, open(
+                archivename, "wb"
+            ) as file_out:
+                inp = file_in.read(10000000)
                 while inp:
-                    co = c.compress(inp)
-                    if co:
-                        fo.write(co)
-                    inp = fi.read(10000000)
-                co = c.flush()
-                if co:
-                    fo.write(co)
-            finally:
-                fo.close()
-                fi.close()
+                    compressed = compressor.compress(inp)
+                    if compressed:
+                        file_out.write(compressed)
+                    inp = file_in.read(10000000)
+                compressed = compressor.flush()
+                if compressed:
+                    file_out.write(compressed)
 
-    def delete_backups(self, names=()):
+    @staticmethod
+    def delete_backups(names=()):
         """Delete backup files."""
-        for n in names:
-            archiveguard = ".".join((n, "grd"))
-            archivename = ".".join((n, "bz2"))
+        for name in names:
+            archiveguard = ".".join((name, "grd"))
+            archivename = ".".join((name, "bz2"))
             try:
                 os.remove(archiveguard)
-            except:
+            except FileNotFoundError:
                 pass
             try:
                 os.remove(archivename)
-            except:
+            except FileNotFoundError:
                 pass
 
-    def restore_backups(self, names=()):
+    @staticmethod
+    def restore_backups(names=()):
         """Restore database from backup files."""
-        for n in names:
-            c = bz2.BZ2Decompressor()
-            archivename = ".".join((n, "bz2"))
-            fi = open(archivename, "rb")
-            fo = open(n, "wb")
-            try:
-                inp = fi.read(1000000)
+        for name in names:
+            decompressor = bz2.BZ2Decompressor()
+            archivename = ".".join((name, "bz2"))
+            with open(archivename, "rb") as file_in, open(
+                name, "wb"
+            ) as file_out:
+                inp = file_in.read(1000000)
                 while inp:
-                    co = c.decompress(inp)
-                    if co:
-                        fo.write(co)
-                    inp = fi.read(1000000)
-            finally:
-                fo.close()
-                fi.close()
+                    decompressed = decompressor.decompress(inp)
+                    if decompressed:
+                        file_out.write(decompressed)
+                    inp = file_in.read(1000000)
         return True
 
-    def delete_database(self, names):
+    @staticmethod
+    def _delete_database_names():
+        """Return tuple of filenames to delete from database directory.
+
+        Subclasses should override this method to delete the relevant files.
+
+        """
+        return ()
+
+    def delete_database(self):
         """Close and delete the open chess database."""
         listnames = set(n for n in os.listdir(self.home_directory))
-        homenames = set(n for n in names if os.path.basename(n) in listnames)
+        homenames = set(
+            n
+            for n in self._delete_database_names()
+            if os.path.basename(n) in listnames
+        )
         if ERROR_LOG in listnames:
             homenames.add(os.path.join(self.home_directory, ERROR_LOG))
         if len(listnames - set(os.path.basename(h) for h in homenames)):
@@ -108,36 +117,38 @@ class Database:
         else:
             message = None
         self.close_database()
-        for h in homenames:
-            if os.path.isdir(h):
-                shutil.rmtree(h, ignore_errors=True)
+        for pathname in homenames:
+            if os.path.isdir(pathname):
+                shutil.rmtree(pathname, ignore_errors=True)
             else:
-                os.remove(h)
+                os.remove(pathname)
         try:
             os.rmdir(self.home_directory)
-        except:
+        except FileNotFoundError:
             pass
         return message
 
     def get_archive_names(self, files=()):
-        """Return names and operating system files for archives and guards"""
+        """Return names and operating system files for archives and guards."""
+        del files
         names = (self.database_file,)
         archives = dict()
         guards = dict()
-        for n in names:
-            archiveguard = ".".join((n, "grd"))
-            archivefile = ".".join((n, "bz2"))
-            for d, f in ((archives, archivefile), (guards, archiveguard)):
-                if os.path.exists(f):
-                    d[n] = f
+        for name in names:
+            archiveguard = ".".join((name, "grd"))
+            archivefile = ".".join((name, "bz2"))
+            for box, file in ((archives, archivefile), (guards, archiveguard)):
+                if os.path.exists(file):
+                    box[name] = file
         return (names, archives, guards)
 
-    def open_after_import_without_backups(self, **ka):
+    def open_after_import_without_backups(self, files=()):
         """Return True after doing database engine specific open actions.
 
         For SQLite3 and Berkeley DB just call open_database.
 
         """
+        del files
         super().open_database()
 
         # Return True to fit behaviour of chessdpt module version of method.
@@ -149,6 +160,7 @@ class Database:
         For SQLite3 and Berkeley DB just call open_database.
 
         """
+        del files
         super().open_database()
 
         # Return True to fit behaviour of chessdpt module version of method.
@@ -160,11 +172,9 @@ class Database:
         It is assumed that the Database Services object exists.
 
         """
-        pass
 
     def adjust_database_for_retry_import(self, files):
-        """Database engine specific actions to do before re-trying an import"""
-        pass
+        """Database engine specific actions done before re-trying an import."""
 
     def mark_partial_positions_to_be_recalculated(self):
         """File all partial positions to be recalculated."""
