@@ -11,35 +11,20 @@ Specification for sqlite3 database, Berkeley DB database and DPT database.
 from solentware_base.core.constants import (
     PRIMARY,
     SECONDARY,
-    DEFER,
     BTOD_FACTOR,
     DEFAULT_RECORDS,
     DEFAULT_INCREASE_FACTOR,
     BTOD_CONSTANT,
     DDNAME,
     FILE,
-    FOLDER,
     FIELDS,
     FILEDESC,
-    FLT,
     INV,
-    UAE,
     ORD,
-    ONM,
-    SPT,
-    EO,
     RRN,
-    BSIZE,
     BRECPPG,
-    BRESERVE,
-    BREUSE,
-    DSIZE,
-    DRESERVE,
-    DPGSRES,
     FILEORG,
     DPT_PRIMARY_FIELD_LENGTH,
-    ACCESS_METHOD,
-    HASH,
 )
 import solentware_base.core.filespec
 
@@ -110,7 +95,6 @@ NEWGAMES_FIELD_VALUE = "changed"
 
 
 class FileSpec(solentware_base.core.filespec.FileSpec):
-
     """Specify a chess database.
 
     Parameters for Berkeley DB, DPT, and Sqlite3, are defined.
@@ -157,9 +141,9 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
     ):
         """Define chess database."""
         dptdsn = FileSpec.dpt_dsn
-        fn = FileSpec.field_name
+        field_name = FileSpec.field_name
 
-        super(FileSpec, self).__init__(
+        super().__init__(
             use_specification_items=use_specification_items,
             dpt_records=dpt_records,
             **{
@@ -174,7 +158,7 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 800,
                     DEFAULT_RECORDS: 10000,
                     DEFAULT_INCREASE_FACTOR: 0.01,
-                    PRIMARY: fn(GAME_FIELD_DEF),
+                    PRIMARY: field_name(GAME_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 200,
                     SECONDARY: {
                         SOURCE_FIELD_DEF: SOURCE_FIELD_DEF.title(),
@@ -193,7 +177,7 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                         PGN_DATE_FIELD_DEF: _PGN_DATE_FIELD_NAME,
                     },
                     FIELDS: {
-                        fn(GAME_FIELD_DEF): None,
+                        field_name(GAME_FIELD_DEF): None,
                         SOURCE_FIELD_DEF.title(): {INV: True, ORD: True},
                         WHITE_FIELD_DEF: {INV: True, ORD: True},
                         BLACK_FIELD_DEF: {INV: True, ORD: True},
@@ -233,14 +217,14 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 100,  # a guess
                     DEFAULT_RECORDS: 10000,
                     DEFAULT_INCREASE_FACTOR: 0.5,
-                    PRIMARY: fn(PARTIAL_FIELD_DEF),
+                    PRIMARY: field_name(PARTIAL_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 127,
                     SECONDARY: {
                         PARTIALPOSITION_NAME_FIELD_DEF: _PP_NAME_FIELD_NAME,
                         NEWGAMES_FIELD_DEF: _NEWGAMES_FIELD_NAME,
                     },
                     FIELDS: {
-                        fn(PARTIAL_FIELD_DEF): None,
+                        field_name(PARTIAL_FIELD_DEF): None,
                         _PP_NAME_FIELD_NAME: {INV: True, ORD: True},
                         _NEWGAMES_FIELD_NAME: {INV: True, ORD: True},
                     },
@@ -256,14 +240,14 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 800,
                     DEFAULT_RECORDS: 100,
                     DEFAULT_INCREASE_FACTOR: 0.01,
-                    PRIMARY: fn(REPERTOIRE_FIELD_DEF),
+                    PRIMARY: field_name(REPERTOIRE_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 200,
                     SECONDARY: {
                         OPENING_FIELD_DEF: None,
                         OPENING_ERROR_FIELD_DEF: _OPENING_ERROR_FIELD_NAME,
                     },
                     FIELDS: {
-                        fn(REPERTOIRE_FIELD_DEF): None,
+                        field_name(REPERTOIRE_FIELD_DEF): None,
                         OPENING_FIELD_DEF: {INV: True, ORD: True},
                         _OPENING_ERROR_FIELD_NAME: {INV: True, ORD: True},
                     },
@@ -279,14 +263,14 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 800,
                     DEFAULT_RECORDS: 100000,
                     DEFAULT_INCREASE_FACTOR: 1.0,
-                    PRIMARY: fn(ANALYSIS_FIELD_DEF),
+                    PRIMARY: field_name(ANALYSIS_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 200,
                     SECONDARY: {
                         ENGINE_FIELD_DEF: ENGINE_FIELD_DEF.title(),
                         VARIATION_FIELD_DEF: VARIATION_FIELD_DEF.title(),
                     },
                     FIELDS: {
-                        fn(ANALYSIS_FIELD_DEF): None,
+                        field_name(ANALYSIS_FIELD_DEF): None,
                         ENGINE_FIELD_DEF.title(): {INV: True, ORD: True},
                         VARIATION_FIELD_DEF.title(): {INV: True, ORD: True},
                     },
@@ -302,13 +286,13 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 100,  # a guess
                     DEFAULT_RECORDS: 10000,
                     DEFAULT_INCREASE_FACTOR: 0.5,
-                    PRIMARY: fn(SELECTION_FIELD_DEF),
+                    PRIMARY: field_name(SELECTION_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 127,
                     SECONDARY: {
                         RULE_FIELD_DEF: RULE_FIELD_DEF.title(),
                     },
                     FIELDS: {
-                        fn(SELECTION_FIELD_DEF): None,
+                        field_name(SELECTION_FIELD_DEF): None,
                         RULE_FIELD_DEF.title(): {INV: True, ORD: True},
                     },
                 },
@@ -323,13 +307,13 @@ class FileSpec(solentware_base.core.filespec.FileSpec):
                     BTOD_CONSTANT: 100,  # a guess
                     DEFAULT_RECORDS: 1000,
                     DEFAULT_INCREASE_FACTOR: 0.5,
-                    PRIMARY: fn(PROGRAM_FIELD_DEF),
+                    PRIMARY: field_name(PROGRAM_FIELD_DEF),
                     DPT_PRIMARY_FIELD_LENGTH: 127,
                     SECONDARY: {
                         COMMAND_FIELD_DEF: COMMAND_FIELD_DEF.title(),
                     },
                     FIELDS: {
-                        fn(PROGRAM_FIELD_DEF): None,
+                        field_name(PROGRAM_FIELD_DEF): None,
                         COMMAND_FIELD_DEF.title(): {INV: True, ORD: True},
                     },
                 },
