@@ -12,12 +12,10 @@ in the *nix environment.
 
 import os
 
+# pylint will give import-error message if bsddb3 is not installed.
+# It is reasonable to not install Python package 'bsddb3'.
+# The importlib module is used to import chessdb if needed.
 from bsddb3.db import (
-    DB_BTREE,
-    DB_HASH,
-    DB_RECNO,
-    DB_DUPSORT,
-    DB_DUP,
     DB_CREATE,
     DB_RECOVER,
     DB_INIT_MPOOL,
@@ -28,12 +26,6 @@ from bsddb3.db import (
 )
 
 from solentware_base import bsddb3_database
-from solentware_base.core.constants import (
-    SUBFILE_DELIMITER,
-    EXISTENCE_BITMAP_SUFFIX,
-    SEGMENT_SUFFIX,
-    SECONDARY,
-)
 
 from ..core.filespec import (
     FileSpec,
@@ -45,7 +37,6 @@ from ..basecore import database
 
 
 class ChessDatabase(database.Database, bsddb3_database.Database):
-
     """Provide access to a database of games of chess."""
 
     _deferred_update_process = os.path.join(
@@ -76,10 +67,10 @@ class ChessDatabase(database.Database, bsddb3_database.Database):
             "maxlocks": DB_ENVIRONMENT_MAXLOCKS,
         }
 
-        super().__init__(dbnames, DBfile, environment)
-
-    def delete_database(self):
-        """Close and delete the open chess database."""
-        return super().delete_database(
-            (self.database_file, self.dbenv.get_lg_dir().decode())
+        super().__init__(
+            dbnames, folder=DBfile, environment=environment, **kargs
         )
+
+    def _delete_database_names(self):
+        """Override and return tuple of filenames to delete."""
+        return (self.database_file, self.dbenv.get_lg_dir().decode())
