@@ -2,21 +2,21 @@
 # Copyright 2016 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Customise delete toplevel to delete Chess Query Language (ChessQL) statement
-record.
+"""Customise delete toplevel to delete ChessQL statement record.
 
 ChessQL statements obey the syntax published for CQL version 6.0.1 (by Gady
 Costeff).
 
 """
+import tkinter
+
 from solentware_grid.gui.datadelete import DataDelete
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
 
 from .cqltoplevel import CQLToplevel
 from .topleveltext import DeleteText
 
 
-class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
+class CQLDbDelete(DeleteText, DataDelete):
     """Delete ChessQL statement from database.
 
     parent is used as the master argument in a CQLToplevel call.
@@ -29,7 +29,7 @@ class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
     Attribute text_name provides the name used in widget titles and message
     text.
 
-    Methods get_title_for_object and set_item, and properties ui_base_table;
+    Methods _get_title_for_object and _set_item, and properties ui_base_table;
     ui_items_in_toplevels; and ui, allow similar methods in various classes
     to be expressed identically and defined once.
 
@@ -37,15 +37,18 @@ class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
 
     text_name = "ChessQL Statement"
 
-    def __init__(self, parent, oldobject, ui=None):
+    def __init__(self, parent=None, oldobject=None, ui=None):
         """Extend and create toplevel widget to delete ChessQL statement."""
-        # Toplevel title set '' in __init__ and to proper value in initialize.
+        # Toplevel title set '' in __init__ and to proper value in _initialize.
         super().__init__(
-            oldobject, parent, CQLToplevel(master=parent, ui=ui), ""
+            instance=oldobject,
+            parent=parent,
+            oldview=CQLToplevel(master=parent, ui=ui),
+            title="",
         )
-        self.initialize()
+        self._initialize()
 
-    def get_title_for_object(self, object_=None):
+    def _get_title_for_object(self, object_=None):
         """Return title for Toplevel containing a ChessQL statement object_.
 
         Default value of object_ is object attribute from DataDelete class.
@@ -62,17 +65,22 @@ class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
 
     @property
     def ui_base_table(self):
+        """Return the User Interface TagRosterGrid object."""
         return self.ui.base_partials
 
     @property
     def ui_items_in_toplevels(self):
+        """Return the User Interface objects in Toplevels."""
         return self.ui.partials_in_toplevels
 
     @property
     def ui(self):
+        """Return the User Interface object from 'read-only' view."""
         return self.oldview.ui
 
-    def set_item(self, view, object_):
+    @staticmethod
+    def _set_item(view, object_):
+        """Populate view with the CQL query extracted from object_."""
         view.cql_statement.process_statement(object_.get_srvalue())
         view.set_and_tag_item_text()
 
@@ -87,12 +95,12 @@ class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
             if self.ui.partial_items.active_item.sourceobject is None:
                 tkinter.messagebox.showinfo(
                     parent=self.parent,
-                    title=self.get_title_for_object(),
+                    title=self._get_title_for_object(),
                     message="".join(
                         (
-                            "Cannot use this delete dialogue while the active ",
-                            "item in cql queries is one opened by menu action ",
-                            "'Position | Partial'.",
+                            "Cannot use this delete dialogue while the ",
+                            "active item in cql queries is one opened by ",
+                            "menu action 'Position | Partial'.",
                         )
                     ),
                 )
@@ -103,12 +111,12 @@ class CQLDbDelete(ExceptionHandler, DeleteText, DataDelete):
             ):
                 tkinter.messagebox.showinfo(
                     parent=self.parent,
-                    title=self.get_title_for_object(),
+                    title=self._get_title_for_object(),
                     message="".join(
                         (
-                            "Cannot use this delete dialogue while the active ",
-                            "item in cql queries is one that displays the record ",
-                            "being deleted.",
+                            "Cannot use this delete dialogue while the ",
+                            "active item in cql queries is one that ",
+                            "displays the record being deleted.",
                         )
                     ),
                 )
