@@ -2,8 +2,10 @@
 # Copyright 2021 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Provide classes which define methods shared by classes in cqldisplay and
-querydisplay modules which display plain text.
+"""Provide classes which define binding and traversal methods for text.
+
+The methods are shared by classes in cqldisplay and querydisplay modules
+which display plain text.
 
 The cqldisplay module has two sets of classes: based on the _CQLDisplay and
 CQLDialogue classes.
@@ -40,9 +42,6 @@ querydisplay modules.
 import tkinter
 import tkinter.messagebox
 
-from solentware_grid.gui.dataedit import RecordEdit
-from solentware_grid.gui.datadelete import RecordDelete
-
 from .eventspec import EventSpec
 from .score import NonTagBind
 
@@ -52,18 +51,7 @@ from .score import NonTagBind
 # because selection rules, CQL statements, and run engine commands, do not
 # have 'analysis'.
 class ShowText:
-
-    """Mixin providing methods shared by the cqldisplay._CQLDisplay and
-    querydisplay.QueryDisplay classes.
-
-    Provide focus switching and widget visibility methods for widgets which
-    display plain text.
-
-    The cqldisplay.CQLDialogue and query.QueryDialogue classes are used in a
-    Toplevel which displays one ChessQL or Selection Rule statement.  The
-    focus switching provided here is not needed.
-
-    """
+    """Provide focus switching and visibility methods for text widgets."""
 
     # The methods identical except for docstrings.  Here 'PGN score' replaces
     # 'game' and 'repertoire'.  The method names already had 'item' rather
@@ -79,105 +67,97 @@ class ShowText:
         self.set_score_pointer_item_navigation_bindings(True)
 
     def bind_for_widget_navigation(self):
-        """Set bindings to give focus to this text statement on pointer click."""
+        """Set pointer bindings to give focus to this text statement."""
         self.set_score_pointer_widget_navigation_bindings(True)
 
-    def get_close_item_events(self):
+    def _get_close_item_events(self):
+        """Return close item event description."""
         return ((EventSpec.display_dismiss, self.delete_item_view),)
 
-    def set_insert_or_delete(self):
-        """Convert edit display to insert display.
-
-        PGN scores displayed for editing from a database are not closed if the
-        database is closed.  They are converted to insert displays and can
-        be used to add new records to databases opened later.
-
-        """
-        self.sourceobject = None
-
     def set_and_tag_item_text(self, reset_undo=False):
         """Delegate to superclass method and set PGN score inactive."""
-
         # Superclass may set self._most_recent_bindings but test below must be
         # against current value.
         mrb = self._most_recent_bindings
 
         super().set_and_tag_item_text(reset_undo=reset_undo)
         if mrb != NonTagBind.NO_EDITABLE_TAGS:
-            for es in (self.get_inactive_button_events(),):
-                self.set_event_bindings_score(es, switch=True)
+            for event_spec in (self._get_inactive_button_events(),):
+                self.set_event_bindings_score(event_spec, switch=True)
 
-    def create_database_submenu(self, menu):
+    def _create_database_submenu(self, menu):
+        """Create and return popup submenu for database events."""
         submenu = tkinter.Menu(master=menu, tearoff=False)
-        self.set_popup_bindings(submenu, self.get_database_events())
+        self._set_popup_bindings(submenu, self._get_database_events())
         return submenu
 
     # The only active bindings compared with displaypgn.ShowPGN.
-    def set_primary_activity_bindings(self, switch=True):
-        """Delegate to toggle other relevant bindings and toggle bindings for
-        database actions, navigation to other widgets, and close widget.
-
-        """
-        super().set_primary_activity_bindings(switch=switch)
-        self.set_database_navigation_close_item_bindings(switch=switch)
+    def _set_primary_activity_bindings(self, switch=True):
+        """Delegate then set navigation and item close bindings."""
+        super()._set_primary_activity_bindings(switch=switch)
+        self._set_database_navigation_close_item_bindings(switch=switch)
 
     # Not relevant away from displaypgn.ShowPGN.
-    # def set_select_variation_bindings(self, switch=True):
+    # def _set_select_variation_bindings(self, switch=True):
     #    """Delegate to toggle other relevant bindings and toggle bindings for
     #    database actions, navigation to other widgets, and close widget.
 
     #    """
-    #    super().set_select_variation_bindings(switch=switch)
-    #    self.set_database_navigation_close_item_bindings(switch=switch)
+    #    super()._set_select_variation_bindings(switch=switch)
+    #    self._set_database_navigation_close_item_bindings(switch=switch)
 
     # The methods identical except for docstrings, and references to
     # self.ui.game_items or self.ui.repertoire_items replaced by property
     # self.ui_displayed_items.
 
-    def next_item(self, event=None):
+    def _next_item(self, event=None):
         """Select next item on display.
 
-        Call _next_item after 1 millisecond to allow message display.
+        Call _cycle_item after 1 millisecond to allow message display.
 
         """
+        del event
         if self.ui_displayed_items.count_items_in_stack() > 1:
             self.ui_set_find_item_games(0)
-            self.score.after(1, self.try_command(self.cycle_item, self.score))
+            self.score.after(1, self.try_command(self._cycle_item, self.score))
 
-    def prior_item(self, event=None):
+    def _prior_item(self, event=None):
         """Select previous item on display.
 
-        Call _prior_item after 1 millisecond to allow message display.
+        Call _cycle_item after 1 millisecond to allow message display.
 
         """
+        del event
         if self.ui_displayed_items.count_items_in_stack() > 1:
             self.ui_set_find_item_games(-2)
             self.score.after(
-                1, self.try_command(self.cycle_item, self.score), True
+                1, self.try_command(self._cycle_item, self.score), True
             )
 
-    # What about current_pgn_score call?
+    # What about _current_pgn_score call?
     def current_item(self, event=None):
         """Select current PGN score on display."""
-
         # cuiai should be referencing self given use of current_item() method,
         # but style of sibling *_item() methods is followed.
         # cuiai was cuigs in gamedisplay, and cuirs in repertoiredisplay,
         # modules originally.
+        del event
         items = self.ui_displayed_items
         if items.count_items_in_stack():
             cuiai = items.active_item
-            self.current_pgn_score(cuiai)
+            self._current_pgn_score(cuiai)
             cuiai.set_statusbar_text()
 
     def traverse_backward(self, event=None):
         """Give focus to previous widget type in traversal order."""
+        del event
         self.set_score_pointer_widget_navigation_bindings(True)
         self.ui.give_focus_backward(self.ui_displayed_items)
         return "break"
 
     def traverse_forward(self, event=None):
         """Give focus to next widget type in traversal order."""
+        del event
         self.set_score_pointer_widget_navigation_bindings(True)
         self.ui.give_focus_forward(self.ui_displayed_items)
         return "break"
@@ -186,7 +166,7 @@ class ShowText:
     # self.ui.configure_game_grid or self.ui.configure_repertoire_grid
     # replaced by property self.ui_configure_item_list_grid.
 
-    def cycle_item(self, prior=False):
+    def _cycle_item(self, prior=False):
         """Select next PGN score on display."""
         items = self.ui_displayed_items
         losefocus = items.active_item
@@ -223,13 +203,13 @@ class ShowText:
     # ui_base_table.  The clarity of both common bits and differences
     # seems to justify the extra syntactic complexity.
 
-    # Probably becomes insert_item_database() in each subclass like in
+    # Probably becomes _insert_item_database() in each subclass like in
     # cqldbshow and all other *db* calls like it.
 
     # This was not going to be moved to displaypgn except insert_game_database,
     # which uses the class attribute pgn_score_updater, was moved.
-    # Both game_updater and pgn_score_updater need more generic names.
-    def game_updater(self, text):
+    # Both _game_updater and pgn_score_updater need more generic names.
+    def _game_updater(self, text):
         """Make and return a chess record containing a single PGN score."""
         updater = self.pgn_score_updater()
         updater.value.load(text)
@@ -239,9 +219,16 @@ class ShowText:
     # _RepertoireDisplay.
     # Replace _pgn_score_ with _item_ to fit with displaypgn.ShowPGN perhaps,
     # but this one will be moved to subclasses.
-    def patch_pgn_score_to_fit_record_change_and_refresh_grid(
+    def _patch_pgn_score_to_fit_record_change_and_refresh_grid(
         self, grid, instance
     ):
+        """Adjust list of games same position if instance is for active game.
+
+        A database update has been done for instance and if that game is the
+        active game, the list of games matching the current position may be
+        out of date.
+
+        """
         if self.ui_displayed_items.is_item_panel_active(self):
             # Patch data structure to look as though the edited record has
             # been read from disk.  That means DataGrid, DisplayItems, and
@@ -252,46 +239,28 @@ class ShowText:
             # on database.
             # instance.newrecord is edited record including index stuff.
             key = None
-            for e, k in enumerate(grid.keys):
-                if instance.key.recno != k[0]:
-                    key = k
+            for grid_key in grid.keys:
+                if instance.key.recno != grid_key[0]:
+                    key = grid_key
                     break
             grid.close_client_cursor()
-            grid.datasource.get_full_position_games(self.get_position_key())
+            grid.datasource.get_full_position_games(self._get_position_key())
             grid.fill_view(currentkey=key, exclude=False)
 
 
 class DisplayText:
+    """Provide method to set database insert and delete event descriptions."""
 
-    """Mixin providing methods shared by the gamedisplay.GameDisplay
-    and repertoiredisplay.RepertoireDisplay classes.
-
-    Named DisplayPGN because ShowPGN is already taken, and when created the
-    only methods in the class are delete_game_database and get_database_events.
-    Both were in GameDisplay and RepertoireDisplay originally.
-
-    insert_game_database is in ShowPGN, not here, because it is also used
-    in the InsertPGN line.
-
-    """
-
-    def get_database_events(self):
+    def _get_database_events(self):
         """Return event description tuple for PGN score database actions."""
         return (
-            (EventSpec.display_insert, self.insert_item_database),
-            (EventSpec.display_delete, self.delete_item_database),
+            (EventSpec.display_insert, self._insert_item_database),
+            (EventSpec.display_delete, self._delete_item_database),
         )
 
 
 class InsertText:
-
-    """Mixin providing methods shared by the gamedisplay.GameDisplayInsert
-    and repertoiredisplay.RepertoireDisplayInsert classes.
-
-    Provide methods involved in generating popup menus relevant to PGN score
-    editing when inserting records.
-
-    """
+    """Provide method which generates database insert event descriptions."""
 
     # The methods identical except for docstrings.  Here 'PGN score' replaces
     # 'game' and 'repertoire'.  The method names already had 'item' rather
@@ -299,48 +268,35 @@ class InsertText:
     # sometimes the method name should be compatible with the 'CQL' and
     # 'Select' classes.
 
-    def get_database_events(self):
+    def _get_database_events(self):
         """Return event description tuple for PGN score database actions."""
-        return ((EventSpec.display_insert, self.insert_item_database),)
+        return ((EventSpec.display_insert, self._insert_item_database),)
 
 
-# Introduced to remove create_primary_activity_popup method from InsertText
+# Introduced to remove _create_primary_activity_popup method from InsertText
 # class: it's presence prevented displaypgn.InsertPGN being a subclass of
 # InsertText.
 # In the PGN classes the displayed list of games depends on which token is
 # current, but in the non-PGN Text classes the displayed list of games is
 # determined by evaluation of a query on demand.
-# When inserting or editing a record the create_primary_activity_popup method
+# When inserting or editing a record the _create_primary_activity_popup method
 # of this class makes an option to demand evaluation available in a popup menu.
 # When showing a record the demand is implicit in making the 'show' widget
 # active.
 # In the PGN classes the demand is always implicit in making a token current,
 # so there is no PGN equivalent of ListGamesText.
 class ListGamesText:
+    """Provide method which creates primary activity popup menu."""
 
-    """Mixin providing methods shared by the cqldisplay._CQLDisplay and
-    and querydisplay._QueryDisplay classes.
-
-    Provide methods involved in generating popup menus relevant to display
-    of game lists when editing records.
-
-    """
-
-    def create_primary_activity_popup(self):
-        popup = super().create_primary_activity_popup()
-        self.add_list_games_entry_to_popup(popup)
+    def _create_primary_activity_popup(self):
+        """Delegate then add list games to popup and return popup menu."""
+        popup = super()._create_primary_activity_popup()
+        self._add_list_games_entry_to_popup(popup)
         return popup
 
 
 class EditText:
-
-    """Mixin providing methods shared by the gamedisplay.GameDisplayEdit
-    and repertoiredisplay.RepertoireDisplayEdit classes.
-
-    Provide methods involved in generating popup menus relevant to PGN score
-    editing when editing records.
-
-    """
+    """Provide method which generates database update event descriptions."""
 
     # The methods identical except for docstrings.  Here 'PGN score' replaces
     # 'game' and 'repertoire'.  The method names already had 'item' rather
@@ -348,12 +304,12 @@ class EditText:
     # sometimes the method name should be compatible with the 'CQL' and
     # 'Select' classes.
 
-    def get_database_events(self):
+    def _get_database_events(self):
         """Return event description tuple for PGN score database actions."""
         return (
-            (EventSpec.display_insert, self.insert_item_database),
-            (EventSpec.display_update, self.update_item_database),
+            (EventSpec.display_insert, self._insert_item_database),
+            (EventSpec.display_update, self._update_item_database),
         )
 
-    # update_game_database becomes update_item_database in cqldispaly and
+    # update_game_database becomes _update_item_database in cqldisplay and
     # querydisplay.
