@@ -10,6 +10,7 @@ An instance of this class fits into the user interface as the only item in a
 new toplevel widget.
 
 """
+import sys
 import os.path
 import tkinter.filedialog
 
@@ -18,15 +19,12 @@ from ..core.engine import Engine
 from . import engine
 from .eventspec import EventSpec
 
-import sys
-
 _win32_platform = sys.platform == "win32"
 _freebsd_platform = sys.platform.startswith("freebsd")
 del sys
 
 
 class EngineEdit(engine.Engine):
-
     """Display a chess engine definition with editing allowed.
 
     Attribute _is_text_editable is True meaning the statement can be
@@ -39,19 +37,21 @@ class EngineEdit(engine.Engine):
 
     def __init__(self, **ka):
         """Extend chess engine definition widget as editor."""
-        super(EngineEdit, self).__init__(**ka)
+        super().__init__(**ka)
         # Context is same for each location so do not need dictionary of
         # Engine instances.
         self.engine_definition_checker = Engine()
 
     def get_primary_activity_events(self):
+        """Return tuple of game navigation keypresses and callbacks."""
         return (
             (EventSpec.databaseenginedisplay_run, self.run_engine),
-            (EventSpec.databaseengineedit_browse, self.browse_engine),
+            (EventSpec.databaseengineedit_browse, self._browse_engine),
         )
 
-    def browse_engine(self, event=None):
+    def _browse_engine(self, event=None):
         """Dialogue to replace chess engine definition in editor."""
+        del event
         if _win32_platform:
             filetypes = (("Chess Engines", "*.exe"),)
         else:
