@@ -2,12 +2,12 @@
 # Copyright 2016 Roger Marsh
 # Licence: See LICENCE (BSD licence)
 
-"""Create widgets that display details of chess engines emabled for database.
-"""
+"""Create widgets to display details of chess engines emabled for database."""
 
 import tkinter
 
 from solentware_grid.gui.datarow import (
+    DataRow,
     GRID_COLUMNCONFIGURE,
     GRID_CONFIGURE,
     WIDGET_CONFIGURE,
@@ -15,18 +15,15 @@ from solentware_grid.gui.datarow import (
     ROW,
 )
 
-from .datarow import DataRow
 from ..core.chessrecord import ChessDBrecordEngine
 from .enginedbedit import EngineDbEdit
 from .enginedbdelete import EngineDbDelete
 from .enginedbshow import EngineDbShow
 from . import constants
-
-ON_DISPLAY_COLOUR = "#eba610"  # a pale orange
+from ..shared.allrow import AllRow
 
 
-class ChessDBrowEngine(ChessDBrecordEngine, DataRow):
-
+class ChessDBrowEngine(AllRow, ChessDBrecordEngine, DataRow):
     """Define row in list of chess engines.
 
     Add row methods to the chess engine record definition.
@@ -56,7 +53,7 @@ class ChessDBrowEngine(ChessDBrecordEngine, DataRow):
         ui - the ChessUI instamce
 
         """
-        super(ChessDBrowEngine, self).__init__()
+        super().__init__()
         self.ui = ui
         self.set_database(database)
         self.row_specification = [
@@ -80,7 +77,7 @@ class ChessDBrowEngine(ChessDBrecordEngine, DataRow):
         oldobject - a ChessDBrecordEngine containing original data
 
         """
-        return EngineDbShow(dialog, oldobject, ui=self.ui)
+        return EngineDbShow(parent=dialog, oldobject=oldobject, ui=self.ui)
 
     def delete_row(self, dialog, oldobject):
         """Return a EngineDbDelete toplevel for oldobject.
@@ -89,7 +86,7 @@ class ChessDBrowEngine(ChessDBrecordEngine, DataRow):
         oldobject - a ChessDBrecordEngine containing original data
 
         """
-        return EngineDbDelete(dialog, oldobject, ui=self.ui)
+        return EngineDbDelete(parent=dialog, oldobject=oldobject, ui=self.ui)
 
     def edit_row(self, dialog, newobject, oldobject, showinitial=True):
         """Return a EngineDbEdit toplevel for oldobject.
@@ -102,34 +99,32 @@ class ChessDBrowEngine(ChessDBrecordEngine, DataRow):
 
         """
         return EngineDbEdit(
-            newobject, dialog, oldobject, showinitial=showinitial, ui=self.ui
+            newobject=newobject,
+            parent=dialog,
+            oldobject=oldobject,
+            showinitial=showinitial,
+            ui=self.ui,
         )
 
-    def grid_row(self, **kargs):
-        """Return super().grid_row(textitems=(...), **kargs).
+    def grid_row(self, textitems=(), **kargs):
+        """Set textitems to engine name, delegate, return response.
 
         Create textitems argument for ChessDBrowEngine instance.
 
+        textitems arguments is ignored and is present for compatibility.
+
         """
-        return super(ChessDBrowEngine, self).grid_row(
-            textitems=(
-                self.value.get_name_text(),
-                # self.value.get_selection_rule_text(),
-            ),
-            **kargs
+        return super().grid_row(
+            textitems=(self.value.get_name_text(),), **kargs
         )
 
-    def grid_row_on_display(self, **kargs):
-        self._current_row_background = ON_DISPLAY_COLOUR
-        return self.grid_row(background=ON_DISPLAY_COLOUR, **kargs)
 
-    def set_background_on_display(self, widgets):
-        self._current_row_background = ON_DISPLAY_COLOUR
-        self.set_background(widgets, self._current_row_background)
+def chess_db_row_engine(chessui):
+    """Return function which returns ChessDBrowEngine instance for chessui.
 
-
-def make_ChessDBrowEngine(chessui):
-    """Make ChessDBrowEngine with reference to ChessUI instance"""
+    The returned function takes an instance of a subclass of Database as
+    it's argument.
+    """
 
     def make_engine(database=None):
         return ChessDBrowEngine(database=database, ui=chessui)
