@@ -12,7 +12,7 @@ PositionScore
 
 import tkinter
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 from pgn_read.core.constants import (
     SEVEN_TAG_ROSTER,
@@ -24,49 +24,33 @@ from pgn_read.core.constants import (
     TAG_RESULT,
 )
 from pgn_read.core.parser import PGN
-from pgn_read.core.squares import Squares
 
 from ..core.pgn import GameDisplayMoves
 from .constants import (
-    LINE_COLOR,
     MOVE_COLOR,
     ALTERNATIVE_MOVE_COLOR,
     VARIATION_COLOR,
     MOVES_PLAYED_IN_GAME_FONT,
     TAGS_VARIATIONS_COMMENTS_FONT,
-    NAVIGATE_TOKEN,
     NAVIGATE_MOVE,
     TOKEN,
     RAV_MOVES,
-    CHOICE,
-    PRIOR_MOVE,
     RAV_SEP,
-    RAV_TAG,
-    ALL_CHOICES,
     POSITION,
     MOVE_TAG,
-    SELECTION,
     ALTERNATIVE_MOVE_TAG,
-    LINE_TAG,
     VARIATION_TAG,
-    LINE_END_TAG,
     START_SCORE_MARK,
-    NAVIGATE_COMMENT,
     TOKEN_MARK,
-    PGN_TAG,
-    ALTERNATIVE_MOVE_COLOR,
-    VARIATION_COLOR,
     SPACE_SEP,
-    NEWLINE_SEP,
-    NULL_SEP,
     MOVETEXT_MOVENUMBER_TAG,
 )
+from ._score_scaffold import _ScoreScaffold
 
 
 # May need to make this a superclass of Tkinter.Text because DataRow method
 # make_row_widgets expects to be able to call Tkinter widget methods.
-class PositionScore(ExceptionHandler):
-
+class PositionScore(Bindings):
     """Chess game score widget composed from a Text widget."""
 
     m_color = MOVE_COLOR
@@ -76,6 +60,7 @@ class PositionScore(ExceptionHandler):
     moves_played_in_game_font = MOVES_PLAYED_IN_GAME_FONT
 
     tags_displayed_last = SEVEN_TAG_ROSTER
+    _context = None
 
     def __init__(
         self,
@@ -98,7 +83,8 @@ class PositionScore(ExceptionHandler):
         Canvas must be square leaving Text at least half the Frame.
 
         """
-        super(PositionScore, self).__init__()
+        del ka
+        super().__init__()
         self.ui = ui
         if tags_variations_comments_font:
             self.tags_variations_comments_font = tags_variations_comments_font
@@ -116,25 +102,23 @@ class PositionScore(ExceptionHandler):
         widget.tag_configure(MOVE_TAG, background=self.m_color)
         widget.tag_configure(ALTERNATIVE_MOVE_TAG, background=self.am_color)
         widget.tag_configure(VARIATION_TAG, background=self.v_color)
-        widget.bind("<Map>", self.try_event(self.on_map))
+        self.bind(widget, "<Map>", function=self.try_event(self._on_map))
         # None implies initial position and is deliberately not a valid Tk tag.
         self.current = None  # Tk tag of current move
         self._clear_tag_maps()
         self.collected_game = None
-        # map_game uses self._force_movenumber to insert movenumber before
-        # black moves after start and end of recursive annotation variation
-        # markers.
-        self._force_movenumber = False
+
+        self.gamevartag = None
+        self._game_scaffold = None
 
     # Nothing needed on <Unmap> event at present
-    def on_map(self, event):
+    def _on_map(self, event):
         """Scroll text of move into current position to left edge of widget.
 
         This is done correctly only if the widget is mapped.  So do it when
         a Map event occurs.
 
         """
-        pass
 
     def _clear_tag_maps(self):
         """Clear mappings of tags and positions.
@@ -153,7 +137,7 @@ class PositionScore(ExceptionHandler):
         self.position_number = 0
 
     def process_score(self, text=None, context=None):
-        """Wrapper for Tkinter.Text configure method for score attribute"""
+        """Populate collected_game with PGN score derived from text."""
         if text:
             self._clear_tag_maps()
             self.collected_game = next(
@@ -184,6 +168,7 @@ class PositionScore(ExceptionHandler):
         editing mode recovers the original score.
 
         """
+        del reset_undo
         self.score.configure(state=tkinter.NORMAL)
         self.score.delete("1.0", tkinter.END)
         self.map_game()
@@ -191,12 +176,12 @@ class PositionScore(ExceptionHandler):
 
     def clear_current_range(self):
         """Remove existing MOVE_TAG ranges."""
-        tr = self.score.tag_ranges(MOVE_TAG)
-        if tr:
-            self.score.tag_remove(MOVE_TAG, tr[0], tr[1])
+        tagrange = self.score.tag_ranges(MOVE_TAG)
+        if tagrange:
+            self.score.tag_remove(MOVE_TAG, tagrange[0], tagrange[1])
 
-    def get_tags_display_order(self):
-        """Return tags in alphabetic order modified by self.tags_displayed_last.
+    def _get_tags_display_order(self):
+        """Return tags in alphabetic order except any chosen to be last.
 
         last=None means do not display the tags: assume tags will be displayed
         in the order they appear in the PGN text.
@@ -218,17 +203,17 @@ class PositionScore(ExceptionHandler):
         if last is None:
             return None
         tag_values = []
-        tags = self.collected_game._tags
-        for tv in sorted(tags.items()):
-            if tv[0] not in last:
-                tag_values.append(tv)
-        for t in last:
-            if t in tags:
-                tag_values.append((t, tags[t]))
+        tags = self.collected_game.pgn_tags
+        for value in sorted(tags.items()):
+            if value[0] not in last:
+                tag_values.append(value)
+        for tag in last:
+            if tag in tags:
+                tag_values.append((tag, tags[tag]))
         return tag_values
 
-    def get_variation_tag_names(self):
-        """Return suffixed RAV_MOVES tag names.
+    def get_variation_tag_name(self):
+        """Return suffixed RAV_MOVES tag name.
 
         The suffixes are arbitrary so increment then generate suffix would be
         just as acceptable but generate then increment uses all numbers
@@ -236,27 +221,26 @@ class PositionScore(ExceptionHandler):
 
         """
         self.variation_number += 1
-        suffix = str(self.variation_number)
-        return "".join((RAV_MOVES, suffix))
+        return "".join((RAV_MOVES, str(self.variation_number)))
 
-    def get_next_positiontag_name(self):
+    def _get_next_positiontag_name(self):
         """Return suffixed POSITION tag name."""
         self.position_number += 1
         return "".join((POSITION, str(self.position_number)))
 
-    def get_position_tag_of_index(self, index):
-        """Return Tk tag name if index is in a position tag"""
-        for tn in self.score.tag_names(index):
-            if tn.startswith(POSITION):
-                return tn
+    def _get_position_tag_of_index(self, index):
+        """Return Tk tag name if index is in a position tag."""
+        for tagname in self.score.tag_names(index):
+            if tagname.startswith(POSITION):
+                return tagname
         return None
 
-    def get_current_tag_and_mark_names(self):
+    def _get_current_tag_and_mark_names(self):
         """Return suffixed POSITION and TOKEN tag and TOKEN_MARK mark names."""
         suffix = str(self.position_number)
         return ["".join((t, suffix)) for t in (POSITION, TOKEN, TOKEN_MARK)]
 
-    def get_tag_and_mark_names(self):
+    def _get_tag_and_mark_names(self):
         """Return suffixed POSITION and TOKEN tag and TOKEN_MARK mark names.
 
         The suffixes are arbitrary so increment then generate suffix would be
@@ -271,7 +255,7 @@ class PositionScore(ExceptionHandler):
         suffix = str(self.position_number)
         return ["".join((t, suffix)) for t in (POSITION, TOKEN, TOKEN_MARK)]
 
-    def insert_token_into_text(self, token, separator):
+    def _insert_token_into_text(self, token, separator):
         """Insert token and separator in widget.  Return boundary indicies.
 
         Indicies for start and end of token text are noted primarily to control
@@ -287,52 +271,46 @@ class PositionScore(ExceptionHandler):
         widget.insert(tkinter.INSERT, separator)
         return start, end, widget.index(tkinter.INSERT)
 
-    def is_currentmove_in_main_line(self):
-        """Return True if currentmove is in the main line tag"""
-        return self.is_index_in_main_line(
+    def _is_currentmove_in_main_line(self):
+        """Return True if currentmove is in the main line tag."""
+        return self._is_index_in_main_line(
             self.score.tag_ranges(self.current)[0]
         )
 
-    def is_index_in_main_line(self, index):
-        """Return True if index is in the main line tag"""
+    def _is_index_in_main_line(self, index):
+        """Return True if index is in the main line tag."""
         return bool(
             self.score.tag_nextrange(
                 self.gamevartag, index, "".join((str(index), "+1 chars"))
             )
         )
 
-    def is_move_in_main_line(self, move):
-        """Return True if move is in the main line"""
-        return self.is_index_in_main_line(self.score.tag_ranges(move)[0])
+    def _is_move_in_main_line(self, move):
+        """Return True if move is in the main line."""
+        return self._is_index_in_main_line(self.score.tag_ranges(move)[0])
 
-    """At present both POSITION<suffix> and TOKEN<suffix> tags exist.
-
-    Now that setting MOVE_TAG has been moved to token-type specific code there
-    is probably no need for both.  TOKEN marks the active text of a POSITION,
-    for example {<active text>} where POSITION includes the surrounding braces,
-    but as active text can vary and when null POSITION is used to set MOVE_TAG
-    might as well refer to POSITION directly.
-
-    This means the set_insert_mark_for_editing and set_bound_marks_for_editing
-    methods do not need to loop through tag names for TOKEN because it starts
-    from a POSITION tag name.
-
-    """
+    # At present both POSITION<suffix> and TOKEN<suffix> tags exist.
+    # Now that setting MOVE_TAG has been moved to token-type specific code
+    # there is probably no need for both.  TOKEN marks the active text of a
+    # POSITION, for example {<active text>} where POSITION includes the
+    # surrounding braces, but as active text can vary and when null
+    # POSITION is used to set MOVE_TAG might as well refer to POSITION
+    # directly.
 
     def _set_square_piece_map(self, position):
         assert len(position) == 1
-        spm = self._square_piece_map
+        spm = self._game_scaffold.square_piece_map
         spm.clear()
-        for p, s in position[0][0]:
-            spm[s] = p
+        for piece, square in position[0][0]:
+            spm[square] = piece
 
     def _modify_square_piece_map(self, position):
         assert len(position) == 2
-        spm = self._square_piece_map
-        for s, p in position[0][0]:
-            del spm[s]
-        for s, p in position[1][0]:
-            spm[s] = p
+        spm = self._game_scaffold.square_piece_map
+        for square, piece in position[0][0]:
+            del spm[square]
+        for square, piece in position[1][0]:
+            spm[square] = piece
 
     # Attempt to re-design map_game method to fit new pgn_read package.
     def map_game(self):
@@ -341,54 +319,48 @@ class PositionScore(ExceptionHandler):
         The tags and marks are used for colouring and navigating the score.
 
         """
-        self._force_movenumber = True
+        self._game_scaffold = _ScoreScaffold(
+            self.get_variation_tag_name(), None
+        )
+        self.gamevartag = self._game_scaffold.vartag
 
-        # With get_current_...() methods as well do not need self._vartag
-        # state attributes.
-        self._vartag = self.get_variation_tag_names()
-        self.gamevartag = self._vartag
-
-        self._square_piece_map = {}
-
-        cg = self.collected_game
-        spm = self._square_piece_map
-        for p, s in cg._initial_position[0]:
-            spm[s] = p
-        assert len(cg._text) == len(cg._position_deltas)
-        for text, delta in zip(cg._text, cg._position_deltas):
-            t0 = text[0]
-            if t0 in "abcdefghKQRBNkqrnO":
-                self.map_move_text(text, delta)
-            elif t0 == "(":
+        game = self.collected_game
+        spm = self._game_scaffold.square_piece_map
+        for piece, square in game.initial_position[0]:
+            spm[square] = piece
+        assert len(game.pgn_text) == len(game.position_deltas)
+        for text, delta in zip(game.pgn_text, game.position_deltas):
+            text0 = text[0]
+            if text0 in "abcdefghKQRBNkqrnO":
+                self._map_move_text(text, delta)
+            elif text0 == "(":
                 self.map_start_rav(text, delta)
-            elif t0 == ")":
+            elif text0 == ")":
                 self.map_end_rav(text, delta)
-            elif t0 in "10*":
+            elif text0 in "10*":
                 self.map_termination(text)
             else:
                 self.map_non_move(text)
-        self.insert_token_into_text(
-            cg._tags.get(TAG_WHITE, DEFAULT_TAG_VALUE), SPACE_SEP
+        self._insert_token_into_text(
+            game.pgn_tags.get(TAG_WHITE, DEFAULT_TAG_VALUE), SPACE_SEP
         )
-        self.insert_token_into_text(
-            cg._tags.get(TAG_RESULT, DEFAULT_TAG_RESULT_VALUE), SPACE_SEP
+        self._insert_token_into_text(
+            game.pgn_tags.get(TAG_RESULT, DEFAULT_TAG_RESULT_VALUE), SPACE_SEP
         )
-        self.insert_token_into_text(
-            cg._tags.get(TAG_BLACK, DEFAULT_TAG_VALUE), SPACE_SEP
+        self._insert_token_into_text(
+            game.pgn_tags.get(TAG_BLACK, DEFAULT_TAG_VALUE), SPACE_SEP
         )
 
-        tr = self.score.tag_nextrange(NAVIGATE_MOVE, "1.0")
-        if tr:
-            self.score.mark_set(START_SCORE_MARK, str(tr[0]))
+        tagrange = self.score.tag_nextrange(NAVIGATE_MOVE, "1.0")
+        if tagrange:
+            self.score.mark_set(START_SCORE_MARK, str(tagrange[0]))
         else:
             self.score.mark_set(START_SCORE_MARK, "1.0")
 
-        # Delete the attributes used to build the self.score Text widget.
-        del self._square_piece_map
-        del self._force_movenumber
-        del self._vartag
+        self._game_scaffold = None
 
-    def compare_two_positions(self, one, two):
+    @staticmethod
+    def compare_two_positions(one, two):
         """Return True if positions one and two are same, otherwise False.
 
         Ignore castling and en passant options when comparing positions.
@@ -410,18 +382,19 @@ class PositionScore(ExceptionHandler):
         if set(one[0]) != set(two[0]):
             return False
         two0 = two[0]
-        for s, p in one[0].items():
-            if p.name != two0[s].name:
+        for square, piece in one[0].items():
+            if piece.name != two0[square].name:
                 return False
         return True
 
-    def map_move_text(self, token, delta):
-        """Add token to game text and modify game position by delta"""
+    def _map_move_text(self, token, delta):
+        """Add token to game text and modify game position by delta."""
         prevcontext, currcontext, nextcontext = self._context
+        scaffold = self._game_scaffold
 
         # Does position in which move is played match the previous or current
         # position in self._context?
-        prev_position = (self._square_piece_map.copy(),) + delta[0][1:]
+        prev_position = (scaffold.square_piece_map.copy(),) + delta[0][1:]
         prev_match_prevcontext = self.compare_two_positions(
             prev_position, prevcontext
         )
@@ -433,7 +406,7 @@ class PositionScore(ExceptionHandler):
 
         # Does position after move is played match the current or next
         # position in self._context?
-        curr_position = (self._square_piece_map.copy(),) + delta[1][1:]
+        curr_position = (scaffold.square_piece_map.copy(),) + delta[1][1:]
         curr_match_currcontext = self.compare_two_positions(
             curr_position, currcontext
         )
@@ -450,79 +423,77 @@ class PositionScore(ExceptionHandler):
             return
         widget = self.score
         if delta[1][1] != FEN_WHITE_ACTIVE:
-            start, end, sepend = self.insert_token_into_text(
+            start, end, sepend = self._insert_token_into_text(
                 str(delta[1][5]) + ".", SPACE_SEP
             )
             widget.tag_add(MOVETEXT_MOVENUMBER_TAG, start, sepend)
-        elif self._force_movenumber:
-            start, end, sepend = self.insert_token_into_text(
+        elif scaffold.force_movenumber:
+            start, end, sepend = self._insert_token_into_text(
                 str(delta[0][5]) + "...", SPACE_SEP
             )
             widget.tag_add(MOVETEXT_MOVENUMBER_TAG, start, sepend)
-        self._force_movenumber = False
-        positiontag = self.get_next_positiontag_name()
-        start, end, sepend = self.insert_token_into_text(token, SPACE_SEP)
-        for tag in positiontag, self._vartag, NAVIGATE_MOVE:
+        scaffold.force_movenumber = False
+        positiontag = self._get_next_positiontag_name()
+        start, end, sepend = self._insert_token_into_text(token, SPACE_SEP)
+        for tag in positiontag, scaffold.vartag, NAVIGATE_MOVE:
             widget.tag_add(tag, start, end)
-        if self._vartag is self.gamevartag:
+        if scaffold.vartag == self.gamevartag:
             widget.tag_add(MOVES_PLAYED_IN_GAME_FONT, start, end)
-        widget.tag_add("".join((RAV_SEP, self._vartag)), start, sepend)
+        widget.tag_add("".join((RAV_SEP, scaffold.vartag)), start, sepend)
         if not (prev_match_prevcontext or prev_match_currcontext):
             # token is move to reach position and different from context
             widget.tag_add(VARIATION_TAG, start, end)
-            pass
         if not (curr_match_currcontext or next_match_nextcontext):
             # token is move out of position and  different from context
             widget.tag_add(ALTERNATIVE_MOVE_TAG, start, end)
-            pass
-        tr = widget.tag_prevrange(self._vartag, start)
-        if not tr:
+        tagrange = widget.tag_prevrange(scaffold.vartag, start)
+        if not tagrange:
             varstack = list(self.varstack)
             while varstack:
                 var = varstack.pop()
                 tpr = widget.tag_prevrange(var, start)
                 if not tpr:
                     break
-                tr = widget.tag_prevrange(var, tpr[0])
-                if tr:
+                tagrange = widget.tag_prevrange(var, tpr[0])
+                if tagrange:
                     break
 
     def map_start_rav(self, token, position):
         """Add token to game text. position is ignored. Return range and prior.
 
-        Variation tags are set for guiding move navigation. self._vartag
-        is placed on
-        a stack for restoration at the end of the variation.
+        Variation tags are set for guiding move navigation.  vartag
+        is placed on a stack for restoration at the end of the variation.
 
         """
+        scaffold = self._game_scaffold
         self._set_square_piece_map(position)
-        widget = self.score
-        self.varstack.append(self._vartag)
-        self._vartag = self.get_variation_tag_names()
-        self.insert_token_into_text(token, SPACE_SEP)
-        self._force_movenumber = True
+        self.varstack.append(scaffold.vartag)
+        scaffold.vartag = self.get_variation_tag_name()
+        self._insert_token_into_text(token, SPACE_SEP)
+        scaffold.force_movenumber = True
 
     def map_end_rav(self, token, position):
         """Add token to game text. position is ignored. Return token range.
 
-        Variation tags are set for guiding move navigation. self._vartag
-        is restored
-        from the stack for restoration at the end of the variation.
+        Variation tags are set for guiding move navigation.  vartag
+        is restored from the stack for restoration at the end of the
+        variation.
 
         """
+        scaffold = self._game_scaffold
         self._set_square_piece_map(position)
-        start, end, sepend = self.insert_token_into_text(token, SPACE_SEP)
-        self._vartag = self.varstack.pop()
-        self._force_movenumber = True
+        self._insert_token_into_text(token, SPACE_SEP)
+        scaffold.vartag = self.varstack.pop()
+        scaffold.force_movenumber = True
 
     def map_termination(self, token):
         """Add token to game text. position is ignored. Return token range."""
-        if self.collected_game._tags.get(TAG_RESULT) != token:
-            self.insert_token_into_text(token, SPACE_SEP)
+        if self.collected_game.pgn_tags.get(TAG_RESULT) != token:
+            self._insert_token_into_text(token, SPACE_SEP)
 
     def map_non_move(self, token):
         """Add token to game text. position is ignored. Return token range."""
-        # self.insert_token_into_text(token, SPACE_SEP)
+        # self._insert_token_into_text(token, SPACE_SEP)
 
     def set_current(self):
         """Remove existing MOVE_TAG ranges and add self.currentmove ranges.
@@ -537,12 +508,13 @@ class PositionScore(ExceptionHandler):
         # Superclass set_current method may adjust bindings so do not call
         # context independent binding setup methods after this method for
         # an event.
-        tr = self.set_current_range()
-        if tr:
-            self.set_move_tag(tr[0], tr[1])
-            return tr
+        tagrange = self._set_current_range()
+        if tagrange:
+            self._set_move_tag(tagrange[0], tagrange[1])
+            return tagrange
+        return None
 
-    def set_current_range(self):
+    def _set_current_range(self):
         """Remove existing MOVE_TAG ranges and add self.currentmove ranges.
 
         Subclasses may adjust the MOVE_TAG range if the required colouring
@@ -554,16 +526,16 @@ class PositionScore(ExceptionHandler):
         """
         self.clear_current_range()
         if self.current is None:
-            return
-        tr = self.score.tag_ranges(self.current)
-        if not tr:
-            return
-        return tr
+            return None
+        tagrange = self.score.tag_ranges(self.current)
+        if not tagrange:
+            return None
+        return tagrange
 
-    def set_move_tag(self, start, end):
+    def _set_move_tag(self, start, end):
         """Add range start to end to MOVE_TAG (which is expected to be empty).
 
-        Assumption is that set_current_range has been called and MOVE_TAG is
+        Assumption is that _set_current_range has been called and MOVE_TAG is
         still empty following that call.
 
         """
