@@ -4,13 +4,14 @@
 
 """Control multiple UCI compliant chess engines."""
 
+import sys
 import tkinter
 import tkinter.messagebox
 import tkinter.filedialog
 
 from solentware_grid.core.dataclient import DataSource
 
-from solentware_misc.gui.exceptionhandler import ExceptionHandler
+from solentware_bind.gui.bindings import Bindings
 
 from uci_net.engine import (
     ReservedOptionNames,
@@ -18,23 +19,28 @@ from uci_net.engine import (
 
 from ..core.uci import UCI as _UCI
 from .enginegrid import EngineGrid
-from .enginerow import make_ChessDBrowEngine
+from .enginerow import chess_db_row_engine
 from ..core.filespec import (
     ENGINE_FILE_DEF,
     COMMAND_FIELD_DEF,
 )
 from .eventspec import EventSpec
 
-import sys
-
 _win32_platform = sys.platform == "win32"
 _freebsd_platform = sys.platform.startswith("freebsd")
 del sys
 
 
-class UCI(ExceptionHandler):
-    def __init__(self, menu_engines, menu_commands):
+class UCI(Bindings):
+    """Provide menu interface to run and control Chess Engines."""
 
+    _command = None
+    _contents = None
+    _spinbox = None
+
+    def __init__(self, menu_engines, menu_commands):
+        """Build the engine and command menus for the menubar."""
+        super().__init__()
         self._do_toplevel = None
         self._show_engines_toplevel = None
         self.database = None
@@ -53,9 +59,9 @@ class UCI(ExceptionHandler):
         for accelerator, function in (
             (
                 EventSpec.menu_engines_position_queues,
-                self.position_queue_status,
+                self._position_queue_status,
             ),
-            (EventSpec.menu_engines_show_engines, self.show_engines),
+            (EventSpec.menu_engines_show_engines, self._show_engines),
             (EventSpec.menu_engines_start_engine, self.start_engine),
             (EventSpec.menu_engines_quit_all_engines, self.quit_all_engines),
         ):
@@ -69,9 +75,9 @@ class UCI(ExceptionHandler):
 
         menu_commands.add_separator()
         for accelerator, function in (
-            (EventSpec.menu_commands_multipv, self.set_multipv),
-            (EventSpec.menu_commands_depth, self.set_depth),
-            (EventSpec.menu_commands_hash, self.set_hash),
+            (EventSpec.menu_commands_multipv, self._set_multipv),
+            (EventSpec.menu_commands_depth, self._set_depth),
+            (EventSpec.menu_commands_hash, self._set_hash),
         ):
             menu_commands.add_command(
                 label=accelerator[1],
@@ -86,12 +92,12 @@ class UCI(ExceptionHandler):
         # menu_commands.add_command(
         #    label='Ucinewgame off',
         #    underline=0,
-        #    command=self.try_command(self.set_ucinewgame_off, menu_commands))
+        #    command=self.try_command(self._set_ucinewgame_off, menu_commands))
         # menu_commands.add_command(
         #    label='Clear Hash off',
         #    underline=0,
         #    command=self.try_command(
-        #        self.set_clear_hash_off, menu_commands))
+        #        self._set_clear_hash_off, menu_commands))
         # menu_commands.add_separator()
 
         # Not implemented at present.
@@ -99,11 +105,11 @@ class UCI(ExceptionHandler):
         # menu_commands.add_command(
         #    label='Go infinite',
         #    underline=3,
-        #    command=self.try_command(self.go_infinite, menu_commands))
+        #    command=self.try_command(self._go_infinite, menu_commands))
         # menu_commands.add_command(
         #    label='Stop',
         #    underline=0,
-        #    command=self.try_command(self.stop, menu_commands))
+        #    command=self.try_command(self._stop, menu_commands))
         # menu_commands.add_separator()
         # menu_commands.add_command(
         #    label='Isready',
@@ -115,20 +121,20 @@ class UCI(ExceptionHandler):
 
     @property
     def show_engines_toplevel(self):
-        """ """
+        """Return toplevel widget."""
         return self._show_engines_toplevel
 
     def remove_engines_and_menu_entries(self):
         """Quit all started UCI compliant Chess Engines."""
         ui_names = set(self.uci.uci_drivers)
         still_alive = self.uci.quit_all_engines()
-        ui_names -= set([n for n, p in still_alive])
+        ui_names -= set(n for n, p in still_alive)
         dead_menu_items = []
-        for i in range(self.menu_engines.index("end") + 1):
-            label = self.menu_engines.entryconfigure(i).get("label")
+        for index in range(self.menu_engines.index("end") + 1):
+            label = self.menu_engines.entryconfigure(index).get("label")
             if label is not None:
                 if label[-1] in ui_names:
-                    dead_menu_items.insert(0, i)
+                    dead_menu_items.insert(0, index)
         for dmi in dead_menu_items:
             self.menu_engines.delete(dmi)
         for name, pid in still_alive:
@@ -160,7 +166,6 @@ class UCI(ExceptionHandler):
 
     def start_engine(self):
         """Start an UCI compliant Chess Engine."""
-
         # Avoid "OSError: [WinError 535] Pipe connected"  at Python3.3 running
         # under Wine on FreeBSD 10.1 by disabling the UCI functions.
         # Assume all later Pythons are affected because they do not install
@@ -197,6 +202,7 @@ class UCI(ExceptionHandler):
             return
 
         def get(event):
+            del event
             command = self._contents.get()
             if command == filename:
                 self.run_engine(filename)
@@ -218,14 +224,14 @@ class UCI(ExceptionHandler):
                     self.run_engine(filename, args=command.strip())
             self._cancel()
 
-        self.do_command(
+        self._do_command(
             filename,
             get,
             hint="".join(
                 (
-                    "\nConsult chess engine's documentation for any arguments ",
-                    "which must be appended to the command.\n\nPress enter to ",
-                    "run engine.\n",
+                    "\nConsult chess engine's documentation for any ",
+                    "arguments which must be appended to the command.",
+                    "\n\nPress enter to run engine.\n",
                 )
             ),
         )
@@ -235,8 +241,8 @@ class UCI(ExceptionHandler):
         self._do_toplevel = None
         del self._contents
 
-    def do_command(self, initial_value, callback, hint=None, wraplength=None):
-
+    def _do_command(self, initial_value, callback, hint=None, wraplength=None):
+        """Start dialogue to send command to chess engines."""
         if self._do_toplevel is not None:
             tkinter.messagebox.showinfo(
                 parent=self.menu_commands,
@@ -276,29 +282,31 @@ class UCI(ExceptionHandler):
         self._contents = tkinter.StringVar()
         self._contents.set(initial_value)
         entrythingy["textvariable"] = self._contents
-        entrythingy.bind("<Key-Return>", callback)
+        self.bind(entrythingy, "<Key-Return>", function=callback)
         entrythingy.focus_set()
 
     def run_engine(self, program_file_name, args=None):
-
+        """Start engine 'program_file_name' and add 'quit' command to menu."""
         self.uci.run_engine(program_file_name, args)
         self.menu_engines.insert_command(
             self.menu_engines.index("end"),
             label=self.uci.uci_drivers_index[self.uci.engine_counter],
-            command=self.make_quit_engine_command(self.uci.engine_counter),
+            command=self._make_quit_engine_command(self.uci.engine_counter),
         )
 
-    def make_quit_engine_command(self, counter):
+    def _make_quit_engine_command(self, counter):
+        """Build and return a function to stop engine numbered 'counter'."""
+
         def quit_engine_command():
             self.quit_engine(counter)
 
         return quit_engine_command
 
     def quit_engine(self, number):
-
+        """Stop the engine at index number in the engine table."""
         ui_name = self.uci.uci_drivers_index[number]
-        for i in range(self.menu_engines.index("end")):
-            label = self.menu_engines.entryconfigure(i).get("label")
+        for index in range(self.menu_engines.index("end")):
+            label = self.menu_engines.entryconfigure(index).get("label")
             if label is not None:
                 if label[-1] == ui_name:
                     if (
@@ -307,7 +315,8 @@ class UCI(ExceptionHandler):
                             title="Quit Engine",
                             message="".join(
                                 (
-                                    "Please confirm request to quit engine\n\n",
+                                    "Please confirm request to quit ",
+                                    "engine\n\n",
                                     ui_name,
                                 )
                             ),
@@ -316,7 +325,7 @@ class UCI(ExceptionHandler):
                     ):
                         continue
                     if self.uci.kill_engine(number):
-                        self.menu_engines.delete(i)
+                        self.menu_engines.delete(index)
                     else:
                         tkinter.messagebox.showinfo(
                             parent=self.menu_engines,
@@ -337,7 +346,12 @@ class UCI(ExceptionHandler):
                         )
 
     def send_to_all_engines(self, event):
+        """Send command to all engines: seems to be unused.
 
+        See uci_net.samples.driver for very similar code.
+
+        """
+        del event
         command = self._contents.get()
         if command.split()[0] != self._command:
             if (
@@ -346,8 +360,8 @@ class UCI(ExceptionHandler):
                     title="Send to Engine",
                     message="".join(
                         (
-                            "Command is not the one used to start dialogue.\n\n",
-                            "Do you want to cancel dialogue?",
+                            "Command is not the one used to start dialogue.",
+                            "\n\nDo you want to cancel dialogue?",
                         )
                     ),
                 )
@@ -358,10 +372,10 @@ class UCI(ExceptionHandler):
                 self._do_toplevel.destroy()
                 self._do_toplevel = None
             return
-        for ui_name, ei in self.uci.uci_drivers.items():
+        for ui_name, engine_interface in self.uci.uci_drivers.items():
             try:
-                ei.to_driver_queue.put(command)
-            except:
+                engine_interface.to_driver_queue.put(command)
+            except Exception:
                 tkinter.messagebox.showinfo(
                     parent=self.menu_commands,
                     title="Send to Engine",
@@ -375,22 +389,24 @@ class UCI(ExceptionHandler):
                         )
                     ),
                 )
+                raise
         del self._command
         del self._contents
         self._do_toplevel.destroy()
         self._do_toplevel = None
 
-    def set_hash(self):
+    def _set_hash(self):
         """Set value of Hash option to use on UCI compliant Chess Engine."""
 
         def get(event):
+            del event
             self.uci.hash_size = self._contents.get()
             self.uci.set_option_on_empty_queues.add(ReservedOptionNames.Hash)
             self._do_toplevel.destroy()
             self._do_toplevel = None
             del self._spinbox
 
-        self.do_spinbox(
+        self._do_spinbox(
             self.uci.hash_size,
             0,
             1000,
@@ -399,46 +415,48 @@ class UCI(ExceptionHandler):
                 (
                     "\nSet the size of hash tables, in mega-bytes, within ",
                     "limits allowed by chess engines.\n\n0 (zero) means use ",
-                    "the default assumed by a chess engine.\n\nPress enter to ",
-                    "set value.\n",
+                    "the default assumed by a chess engine.\n\nPress enter ",
+                    "to set value.\n",
                 )
             ),
         )
 
-    def set_multipv(self):
+    def _set_multipv(self):
         """Set value of MultiPV option to use on UCI compliant Chess Engine."""
 
         def get(event):
+            del event
             self.uci.multipv = self._contents.get()
             self._do_toplevel.destroy()
             self._do_toplevel = None
             del self._spinbox
 
-        self.do_spinbox(
+        self._do_spinbox(
             self.uci.multipv,
             0,
             100,
             get,
             hint="".join(
                 (
-                    "\nSet the number of variations returned by chess engines ",
-                    "which support the MultiPV option.\n\n0 (zero) means use ",
-                    "the default assumed by a chess engine.\n\nPress enter to ",
-                    "set value.\n",
+                    "\nSet the number of variations returned by chess ",
+                    "engines which support the MultiPV option.\n\n0 (zero) ",
+                    "means use the default assumed by a chess engine.\n\n",
+                    "Press enter to set value.\n",
                 )
             ),
         )
 
-    def set_depth(self):
+    def _set_depth(self):
         """Set depth to use in go commands to UCI compliant Chess Engine."""
 
         def get(event):
+            del event
             self.uci.go_depth = self._contents.get()
             self._do_toplevel.destroy()
             self._do_toplevel = None
             del self._spinbox
 
-        self.do_spinbox(
+        self._do_spinbox(
             self.uci.go_depth,
             0,
             200,
@@ -452,17 +470,17 @@ class UCI(ExceptionHandler):
         )
 
     def _modify_command_menu_item(self, old, new, command):
-        for i in range(self.menu_commands.index("end")):
-            label = self.menu_commands.entryconfigure(i).get("label")
+        for index in range(self.menu_commands.index("end")):
+            label = self.menu_commands.entryconfigure(index).get("label")
             if label is not None:
                 if label[-1] == old:
                     self.menu_commands.entryconfigure(
-                        i,
+                        index,
                         label=new,
                         command=self.try_command(command, self.menu_commands),
                     )
 
-    def set_ucinewgame_off(self):
+    def _set_ucinewgame_off(self):
         """Set to not use ucinewgame command when navigating games."""
         if (
             tkinter.messagebox.askquestion(
@@ -470,14 +488,14 @@ class UCI(ExceptionHandler):
                 title="Ucinewgame OFF",
                 message="".join(
                     (
-                        "Turn use of ucinewgame command OFF when navigating in or ",
-                        "between game scores?\n\n",
-                        "Consult engine documentation for implications of using, ",
-                        "or not using, the ucinewgame command.\n\n",
-                        "UCI specification states new GUIs should support ucinewgame ",
-                        "command, and engines should not expect ucinewgame commands ",
-                        "if the ucinewgame command is not used before the first ",
-                        "position command. (August 2015)",
+                        "Turn use of ucinewgame command OFF when navigating ",
+                        "in or between game scores?\n\nConsult engine ",
+                        "documentation for implications of using, or not ",
+                        "using, the ucinewgame command.\n\nUCI specification ",
+                        "states new GUIs should support ucinewgame command, ",
+                        "and engines should not expect ucinewgame commands ",
+                        "if the ucinewgame command is not used before the ",
+                        "first position command. (August 2015)",
                     )
                 ),
             )
@@ -485,10 +503,10 @@ class UCI(ExceptionHandler):
         ):
             self.uci.use_ucinewgame = False
             self._modify_command_menu_item(
-                "Ucinewgame off", "Ucinewgame on", self.set_ucinewgame_on
+                "Ucinewgame off", "Ucinewgame on", self._set_ucinewgame_on
             )
 
-    def set_ucinewgame_on(self):
+    def _set_ucinewgame_on(self):
         """Set to use ucinewgame command when navigating games."""
         if (
             tkinter.messagebox.askquestion(
@@ -496,14 +514,14 @@ class UCI(ExceptionHandler):
                 title="Ucinewgame ON",
                 message="".join(
                     (
-                        "Turn use of ucinewgame command ON when navigating in or ",
-                        "between game scores?\n\n",
-                        "Consult engine documentation for implications of using, ",
-                        "or not using, the ucinewgame command.\n\n",
-                        "UCI specification states new GUIs should support ucinewgame ",
-                        "command, and engines should not expect ucinewgame commands ",
-                        "if the ucinewgame command is not used before the first ",
-                        "position command. (August 2015)",
+                        "Turn use of ucinewgame command ON when navigating ",
+                        "in or between game scores?\n\nConsult engine ",
+                        "documentation for implications of using, or not ",
+                        "using, the ucinewgame command.\n\nUCI specification ",
+                        "states new GUIs should support ucinewgame command, ",
+                        "and engines should not expect ucinewgame commands ",
+                        "if the ucinewgame command is not used before the ",
+                        "first position command. (August 2015)",
                     )
                 ),
             )
@@ -511,21 +529,19 @@ class UCI(ExceptionHandler):
         ):
             self.uci.use_ucinewgame = True
             self._modify_command_menu_item(
-                "Ucinewgame on", "Ucinewgame off", self.set_ucinewgame_off
+                "Ucinewgame on", "Ucinewgame off", self._set_ucinewgame_off
             )
 
-    def stop(self):
+    def _stop(self):
         """Send stop command to UCI compliant Chess Engines."""
-
         tkinter.messagebox.showinfo(
             parent=self.menu_commands,
             title="Stop Command",
             message="Stop not implemented.",
         )
 
-    def go_infinite(self):
+    def _go_infinite(self):
         """Send go infinite command to UCI compliant Chess Engines."""
-
         tkinter.messagebox.showinfo(
             parent=self.menu_commands,
             title="Go Infinite Command",
@@ -534,19 +550,22 @@ class UCI(ExceptionHandler):
 
     def isready(self):
         """Send isready command to UCI compliant Chess Engines."""
-
         tkinter.messagebox.showinfo(
             parent=self.menu_commands,
             title="Isready Command",
             message="Isready not implemented.",
         )
 
-    def do_spinbox(
-        self, initial_value, from_, to, callback, hint=None, wraplength=None
+    # pylint message invalid-name for to argument.
+    # Name was 'to' to fit tkinter.Spinbox argument name: change to 'to_' to
+    # resolve pylint message.  ('from' is Python syntax so that got changed
+    # too, right at start of module's life.)
+    def _do_spinbox(
+        self, initial_value, from_, to_, callback, hint=None, wraplength=None
     ):
-
-        # Comapare with show_engines() method.
-        # The after() technique used in show_engines does not help here to
+        """Show spinbox to get value in range from_:to with initial value."""
+        # Comapare with _show_engines() method.
+        # The after() technique used in _show_engines does not help here to
         # guarantee display of the new Toplevel on second and subsequent use.
         # But the problem is seen only when the X server is on a different box
         # than the ChessTab process.
@@ -570,13 +589,14 @@ class UCI(ExceptionHandler):
             del self._spinbox
 
         def destroy(event=None):
+            del event
             self._do_toplevel = None
 
         self._spinbox = initial_value
         self._do_toplevel = tkinter.Toplevel(
             master=self.menu_engines.winfo_toplevel()
         )
-        self._do_toplevel.bind("<Destroy>", destroy)
+        self.bind(self._do_toplevel, "<Destroy>", function=destroy)
         if hint:
             if wraplength is None:
                 wraplength = 400
@@ -596,14 +616,14 @@ class UCI(ExceptionHandler):
             underline=0,
             command=self.try_command(cancel, buttonbar),
         ).pack(expand=tkinter.TRUE, side=tkinter.LEFT)
-        entrythingy.configure(from_=from_, to=to, increment=1)
+        entrythingy.configure(from_=from_, to=to_, increment=1)
         self._contents = tkinter.IntVar()
         self._contents.set(initial_value)
         entrythingy["textvariable"] = self._contents
-        entrythingy.bind("<Key-Return>", callback)
+        self.bind(entrythingy, "<Key-Return>", function=callback)
         entrythingy.focus_set()
 
-    def show_engines(self):
+    def _show_engines(self):
         """Show Chess Engine Descriptions on database."""
         if self._show_engines_toplevel is not None:
             tkinter.messagebox.showinfo(
@@ -619,6 +639,7 @@ class UCI(ExceptionHandler):
             return
 
         def destroy(event=None):
+            del event
             if self._show_engines_toplevel is not None:
                 self._close_engine_grid()
             self._show_engines_toplevel = None
@@ -627,7 +648,7 @@ class UCI(ExceptionHandler):
             master=self.menu_engines.winfo_toplevel()
         )
         self._show_engines_toplevel.wm_title("Chess Engines")
-        self._show_engines_toplevel.bind("<Destroy>", destroy)
+        self.bind(self._show_engines_toplevel, "<Destroy>", function=destroy)
         self._close_engine_grid()
 
         # The after_idle version makes it less common for the Toplevel to not
@@ -676,7 +697,7 @@ class UCI(ExceptionHandler):
                     self.database,
                     ENGINE_FILE_DEF,
                     COMMAND_FIELD_DEF,
-                    make_ChessDBrowEngine(self),
+                    chess_db_row_engine(self),
                 ),
                 self.base_engines.on_data_change,
             )
@@ -690,28 +711,28 @@ class UCI(ExceptionHandler):
         self.visible_scrollbars = True
         exceptions = []
         for items in (self.engines_in_toplevels,):
-            for i in items:
+            for item in items:
                 try:
-                    i.show_scrollbars()
+                    item.show_scrollbars()
                 except tkinter.TclError:
-                    exceptions.append(i, items)
-        for i, items in exceptions:
-            items.remove(i)
+                    exceptions.append(item, items)
+        for item, items in exceptions:
+            items.remove(item)
 
     def hide_scrollbars(self):
         """Show the scrollbars in the engine definition display widgets."""
         self.visible_scrollbars = False
         exceptions = []
         for items in (self.engines_in_toplevels,):
-            for i in items:
+            for item in items:
                 try:
-                    i.hide_scrollbars()
+                    item.hide_scrollbars()
                 except tkinter.TclError:
-                    exceptions.append((i, items))
-        for i, items in exceptions:
-            items.remove(i)
+                    exceptions.append((item, items))
+        for item, items in exceptions:
+            items.remove(item)
 
-    def position_queue_status(self):
+    def _position_queue_status(self):
         """Display counts of position queued for analysis by engines."""
         pending_counts = []
         for engine, pending in self.uci.positions_pending.items():
@@ -726,8 +747,8 @@ class UCI(ExceptionHandler):
             )
             return
         pce = []
-        for e, pc in sorted(pending_counts):
-            pce.append("\t".join((str(pc), e)))
+        for engine, count in sorted(pending_counts):
+            pce.append("\t".join((str(count), engine)))
         tkinter.messagebox.showinfo(
             parent=self.menu_commands,
             title="Position Queues",
@@ -740,7 +761,7 @@ class UCI(ExceptionHandler):
             ),
         )
 
-    def set_clear_hash_off(self):
+    def _set_clear_hash_off(self):
         """Set to not clear hash tables before position go command sequence."""
         if (
             tkinter.messagebox.askquestion(
@@ -748,9 +769,9 @@ class UCI(ExceptionHandler):
                 title="Clear Hash OFF",
                 message="".join(
                     (
-                        "Turn OFF clear hash tables before analysing a position?\n\n",
-                        "Consult engine documentation for implications of clearing ",
-                        "hash tables or not.",
+                        "Turn OFF clear hash tables before analysing a ",
+                        "position?\n\nConsult engine documentation for ",
+                        "implications of clearing hash tables or not.",
                     )
                 ),
             )
@@ -758,10 +779,10 @@ class UCI(ExceptionHandler):
         ):
             self.uci.clear_hash = False
             self._modify_command_menu_item(
-                "Clear Hash off", "Clear Hash on", self.set_clear_hash_on
+                "Clear Hash off", "Clear Hash on", self._set_clear_hash_on
             )
 
-    def set_clear_hash_on(self):
+    def _set_clear_hash_on(self):
         """Set to clear hash tables before position go command sequence."""
         if (
             tkinter.messagebox.askquestion(
@@ -769,9 +790,9 @@ class UCI(ExceptionHandler):
                 title="Clear Hash ON",
                 message="".join(
                     (
-                        "Turn ON clear hash tables before analysing a position?\n\n",
-                        "Consult engine documentation for implications of clearing ",
-                        "hash tables or not.",
+                        "Turn ON clear hash tables before analysing a ",
+                        "position?\n\nConsult engine documentation for ",
+                        "implications of clearing hash tables or not.",
                     )
                 ),
             )
@@ -779,5 +800,5 @@ class UCI(ExceptionHandler):
         ):
             self.uci.clear_hash = True
             self._modify_command_menu_item(
-                "Clear Hash on", "Clear Hash off", self.set_clear_hash_off
+                "Clear Hash on", "Clear Hash off", self._set_clear_hash_off
             )
