@@ -4,7 +4,9 @@
 
 """Read a PGN file and display timing profile."""
 
-import cProfile, pstats, io
+import cProfile
+import pstats
+import io
 import tkinter
 
 from pgn_read.samples import _utilities
@@ -13,6 +15,8 @@ from ..core.pgn import GameUpdate
 
 
 class Main(_utilities.Main):
+    """Collect timing profile for processing a PGN file."""
+
     def process_pgn_file(self, event=None):
         """Process PGN file."""
         pr = cProfile.Profile()
