@@ -5,9 +5,9 @@
 """Import directory of PGN files with sqlite.chesssqlite3du to database."""
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
 
     from .directory_widget import DirectoryWidget
     from ..sqlite.chesssqlite3du import chess_sqlite3du
 
-    DirectoryWidget(chess_sqlite3du, 'sqlite3')
+    DirectoryWidget(chess_sqlite3du, "sqlite3")
